function theta = CalcTheta(x,wbarHat,params,order,opts,solveOpts)
%%Model m-file for Labor Market Participation and the Minimum Wage
%Author: Adrian Masters and Ben Griffy
%Date: July 2020

% inputs
% x(1): market tightness (theta)
% x(2): cut-off productivity in planner's problem, minimum wage in decentralized problem.


[pphi,eeta,bbeta,a,z,r,llambda,m,mmu,ssigma,lb,ub,pphiDelt,zDelt,wbarDelt,wbinDelt,N,T,wbar,mFun,dmFun,wageFun,pFun,udotFun] = Parameters(params, order, opts);

if strcmpi(solveOpts.prob,'planner') || strcmpi(solveOpts.prob,'plannerfixed')

    eqm=zeros(2,1);

    if x(1)<=0 || x(2)<z/(1-pphi)
        eqm=10000*ones(2,1);
        % eqm = NaN
        % err = 1
        return
    end


    E=LNCalcExp(params,order,opts,x(2),inf);    % expected prod above w

    matRate = mFun(x(1));
    dmatRate = dmFun(x(1));

    % consistent with paper, eq 3
    eqm(1)=dmatRate*((1-pphi)*E-z)-a*(r+llambda+matRate*(1-eeta));

    % consistent with paper, eq 4
    eqm(2)=dmatRate*(1-pphi)*(matRate*x(2)+llambda*E)-(matRate+llambda)*(a*llambda+z*dmatRate);


    % ssr = eqm'*eye(2)*eqm;

else

    eqm=zeros(2,1);

    if x(1)<=0
        eqm=10000*ones(2,1);
        % eqm=NaN
        % err = 1
        return
    end

    theta = x;

    % matching rate at theta* and derivative of matching function at theta*
    matRate = mFun(theta);


    % convenient definitions
    rlbm=r+llambda+bbeta*matRate;



    % ps = pFun(x(2),theta);

    Ebar=LNCalcExp(params,order,opts,x(2),inf);    % expected prod above wbar

    % eq. 10 in sect. 3 of EER submission
    theta = matRate*(1-bbeta)*((1-pphi)*Ebar-z)./(a*rlbm);  % free entry condition(Ah.2.4)


end

end
