function MainFindings(params, order, moments, resultsSeries, opts)
%% MainFindings m-file for Labor Market Participation and the Minimum Wage
%Author: Adrian Masters and Ben Griffy
%Date: July 2020
%Description: this quantifies all the key results for the paper. It solves each problem and then compares the equilibrium either directly or using plots of equilibrium outcomes.

    opts.test = 'n';
    [pphi,eeta,bbeta,a,z,r,llambda,m,mmu,ssigma,lb,ub,pphiDelt,zDelt,wbarDelt,wbinDelt,N,T,wbar,mFun,dmFun,wageFun,pFun,udotFun] = Parameters(params, order, opts);

    if isequal(exist(fullfile(pwd,opts.graphics_path,'Results/'),'dir'),7);
        results_graphics_path = fullfile(pwd,opts.graphics_path,'Results/');
    else
        results_graphics_path = fullfile(pwd,opts.graphics_path,'Results/');
        mkdir(fullfile(pwd,opts.graphics_path,'Results/'));
    end



    if opts.solveLaissezFaire == 'y' % solve the Laissez-Faire version of the model (\bar{w} = z)
        output_pathInit = opts.output_path;
        opts.output_path = '/output/LaissezFaire/';
        opts.simName = 'LaissezFaire';
        opts.fancySimName = 'Laissez-faire Bargained';
        opts.test = 'LaissezFaire';
        solveOpts.prob = 'decentralfixed';
        wbarInit = params(find(strcmp(order, 'wbar')));
        params(find(strcmp(order, 'wbar'))) = z;
        ModelMaxWelf_Wrapper(params, order, opts, [], [], solveOpts);
        params(find(strcmp(order, 'wbar'))) = wbarInit;
        opts.output_path = output_pathInit;
    end



    if opts.solvePlanner == 'y' % solve the Planner's problem
        output_pathInit = opts.output_path;

        opts.output_path = '/output/LaissezFaire/';
        matfile = fullfile(pwd,opts.output_path,'solutionDecentral.mat');
        load(matfile);
        initThetaHat = thetaHat;
        initWbarHat = wbarHat;
        clear thetaHat wbarHat;

        opts.output_path = '/output/Planner/';
        opts.simName = 'Planner';
        opts.fancySimName = 'Planners Problem';
        solveOpts.prob = 'planner';
        ModelMaxWelf_Wrapper(params, order, opts, initThetaHat, initWbarHat, solveOpts);
        opts.output_path = output_pathInit;
    end

    if opts.solveDecentral == 'y'
        output_pathInit = opts.output_path;

        % load the Laissez-Faire starting point to solve for the optimal minimum wage by maximizing transition welfare
        opts.output_path = '/output/LaissezFaire/';
        matfile = fullfile(pwd,opts.output_path,'solutionDecentral.mat');
        load(matfile);
        initThetaHat = thetaHat;
        initWbarHat = wbarHat;
        clear thetaHat wbarHat;

        opts.output_path = '/output/Decentralized/';
        opts.simName = 'Decentralized';
        opts.fancySimName = 'Decentralized Problem';
        solveOpts.prob = 'decentral';
        ModelMaxWelf_Wrapper(params, order, opts, initThetaHat, initWbarHat, solveOpts);
        opts.output_path = output_pathInit;
    end

    if opts.solveCalibrated == 'y'
        output_pathInit = opts.output_path;

        % load the Laissez-Faire starting point to solve for theta over the transition        
        opts.output_path = '/output/LaissezFaire/';
        matfile = fullfile(pwd,opts.output_path,'solutionDecentral.mat');
        load(matfile);
        initThetaHat = thetaHat;
        initWbarHat = wbarHat;
        clear thetaHat wbarHat;

        opts.output_path = '/output/Calibrated/';
        opts.simName = 'Calibrated';
        opts.fancySimName = 'Calibrated Problem';
        solveOpts.prob = 'calib';
        ModelMaxWelf_Wrapper(params, order, opts, initThetaHat, initWbarHat, solveOpts);
        opts.output_path = output_pathInit;
    end

    if opts.decompExperiments == 'y' % decomposition experiments
        output_pathInit = opts.output_path;
        opts.output_path = '/output/LaissezFaireDecompPolicies/';
        opts.simName = 'LaissezFaireDecompPolicies';
        opts.fancySimName = 'Laissez-faire Bargained';
        opts.test = 'LaissezFaireDecompPolicies';
        solveOpts.prob = 'decentralfixed';
        wbarInit = params(find(strcmp(order, 'wbar')));
        params(find(strcmp(order, 'wbar'))) = z;
        ModelMaxWelf_Wrapper(params, order, opts, [], [], solveOpts);
        params(find(strcmp(order, 'wbar'))) = wbarInit;

        matfile = fullfile(pwd,opts.output_path,'solutionDecentral.mat');
        load(matfile);

        initThetaHat = thetaHat;
        initWbarHat = wbarHat;

        clear thetaHat wbarHat;

        opts.output_path = '/output/CalibDecompPolicies/'; % set output path for resulting decision rules
        opts.simName = 'CalibDecompPolicies'; % give the simulation a name
        opts.fancySimName = 'Calibration Decomp Bargained'; % give it a fancy name
        opts.test = 'CalibDecompPolicies'; % define the experiment to be done (generally same as simName)
        solveOpts.prob = 'decentralfixed'; % define the version of the model being solved
        ModelMaxWelf_Wrapper(params, order, opts, initThetaHat, initWbarHat, solveOpts);

        opts.output_path = '/output/OptimalDecompParticipation/';
        opts.simName = 'OptimalDecompParticipation';
        opts.fancySimName = 'Optimal Participation Decomp';
        opts.test = 'OptimalDecompParticipation';
        solveOpts.prob = 'decentralparticipation';
        ModelMaxWelf_Wrapper(params, order, opts, initThetaHat, initWbarHat, solveOpts);

        opts.output_path = '/output/OptimalDecompPoliciesMW/';
        opts.simName = 'OptimalDecompPoliciesMW';
        opts.fancySimName = 'Optimal PoliciesMW Decomp';
        opts.test = 'OptimalDecompPoliciesMW';
        solveOpts.prob = 'decentral';
        ModelMaxWelf_Wrapper(params, order, opts, initThetaHat, initWbarHat, solveOpts);

        matfile = fullfile(pwd,opts.output_path,'solutionDecentral.mat');
        load(matfile);

        opts.output_path = '/output/OptimalDecompParticipationMW/';
        opts.simName = 'OptimalDecompParticipationMW';
        opts.fancySimName = 'Optimal Participation Decomp';
        opts.test = 'OptimalDecompParticipationMW';
        wbarInit = params(find(strcmp(order, 'wbar')));
        params(find(strcmp(order, 'wbar'))) = wbarHat; 
        solveOpts.prob = 'decentralparticipationfixed';
        ModelMaxWelf_Wrapper(params, order, opts, initThetaHat, initWbarHat, solveOpts);
        params(find(strcmp(order, 'wbar'))) = wbarInit;

        clear wbarHat thetaHat;

        opts.output_path = '/output/OptimalDecompPoliciesUI/';
        opts.simName = 'OptimalDecompPoliciesUI';
        opts.fancySimName = 'Optimal PoliciesUI Decomp';
        opts.test = 'OptimalDecompPoliciesUI';
        bbetaInit = params(find(strcmp(order, 'bbeta')));
        solveOpts.prob = 'decentral';
        ModelUI_Wrapper(params, order, opts, solveOpts);
        params(find(strcmp(order, 'bbeta'))) = bbetaInit;

        matfile = fullfile(pwd,opts.output_path,'solutionUIDecentral.mat');
        load(matfile);

        opts.output_path = '/output/OptimalDecompParticipationUI/';
        opts.simName = 'OptimalDecompParticipationUI';
        opts.fancySimName = 'Optimal Participation Decomp';
        opts.test = 'OptimalDecompParticipationUI';
        wbarInit = params(find(strcmp(order, 'wbar')));
        params(find(strcmp(order, 'wbar'))) = zHat; % \bar{w} is set to 0 in our optimal UI experiments
        solveOpts.prob = 'decentralparticipationfixed';
        ModelMaxWelf_Wrapper(params, order, opts, initThetaHat, initWbarHat, solveOpts);
        params(find(strcmp(order, 'wbar'))) = wbarInit;

        clear wbarHat thetaHat;

        opts.output_path = '/output/OptimalDecompPoliciesBoth/';
        opts.simName = 'OptimalDecompPoliciesBoth';
        opts.fancySimName = 'Optimal PoliciesBoth Decomp';
        opts.test = 'OptimalDecompPoliciesBoth';
        solveOpts.prob = 'decentralboth';
        ModelMaxWelfMWUI_Wrapper(params, order, opts, initThetaHat, initWbarHat, solveOpts);

        opts.output_path = '/output/OptimalDecompPoliciesVacMW/';
        opts.simName = 'OptimalDecompPoliciesVac';
        opts.fancySimName = 'Optimal PoliciesVac Decomp';
        opts.test = 'OptimalDecompPoliciesVac';
        solveOpts.prob = 'decentralvacmw';
        ModelMaxWelfVac_Wrapper(params, order, opts, initThetaHat, initWbarHat, solveOpts);

        opts.output_path = '/output/OptimalDecompPoliciesVacUI/';
        opts.simName = 'OptimalDecompPoliciesVac';
        opts.fancySimName = 'Optimal PoliciesVac Decomp';
        opts.test = 'OptimalDecompPoliciesVac';
        solveOpts.prob = 'decentralvacui';
        ModelMaxWelfVac_Wrapper(params, order, opts, initThetaHat, initWbarHat, solveOpts);

        clear wbarHat thetaHat;

        opts.output_path = output_pathInit;

    end


    if opts.policyExperiments == 'y'
        output_pathInit = opts.output_path;

        opts.output_path = '/output/LaissezFaire/';
        matfile = fullfile(pwd,opts.output_path,'solutionDecentral.mat');
        load(matfile);
        initThetaHat = thetaHat;
        initWbarHat = wbarHat;
        clear thetaHat wbarHat;


        if opts.policyMW == 'y'
            opts.output_path = '/output/OptimalMW/';
            opts.simName = 'OptimalMW';
            opts.fancySimName = 'Optimal PoliciesMW Decomp';
            opts.test = 'OptimalMW';
            solveOpts.prob = 'decentral';
            ModelMaxWelf_Wrapper(params, order, opts, initThetaHat, initWbarHat, solveOpts);
        end


        if opts.policyUI == 'y'
            opts.output_path = '/output/OptimalUI/';
            opts.simName = 'OptimalUI';
            opts.fancySimName = 'General Eqm. UI';
            opts.test = 'OptimalUI';
            solveOpts.prob = 'decentral';
            ModelUI_Wrapper(params, order, opts, solveOpts);
        end


        if opts.policyBoth == 'y'
            opts.output_path = '/output/OptimalBoth/';
            opts.simName = 'OptimalBoth';
            opts.fancySimName = 'Optimal Policies Both Decomp';
            opts.test = 'OptimalBoth';
            bbetaInit = params(find(strcmp(order, 'bbeta')));
            solveOpts.prob = 'decentralboth';
            ModelMaxWelfMWUI_Wrapper(params, order, opts, initThetaHat, initWbarHat, solveOpts);
            % ModelMaxWelf_Wrapper(params, order, opts, solveOpts);
            params(find(strcmp(order, 'bbeta'))) = bbetaInit;
        end

        opts.output_path = output_pathInit;
    end


    if opts.CompDecompPolicies == 'y'

        modelNames = {'Laissez-faire','Optimal\\\\Participation','Min. Wage\\\\Participation ($\\hat{p}=\\bar{w}^{*}$)','Optimal\\\\Min. Wage'};
        modelPaths = {'LaissezFaireDecompPolicies','OptimalDecompParticipation','OptimalDecompParticipationMW','OptimalDecompPoliciesMW'};
        modelType = {'Decentral','DecentralParticipation','DecentralParticipation','Decentral'};
        testResults = {'uratem','NILF','thetaHat','swagep','welfareratio'};

        opts.testGroup = 'PaperDecompositionExperimentMW';
        opts.testBaseName = 'Laissez-faire';
        opts.testInitState = 'Laissez-faire';

        MainFindingsAverages_Wrapper(params, order, opts, moments, modelNames, modelPaths, modelType, testResults);
        opts = rmfield(opts,'testBaseName');

        modelNames = {'Calibrated','Optimal\\\\Participation','Min. Wage\\\\Participation ($\\hat{p}=\\bar{w}^{*}$)','Optimal\\\\Min. Wage'};
        modelPaths = {'CalibDecompPolicies','OptimalDecompParticipation','OptimalDecompParticipationMW','OptimalDecompPoliciesMW'};
        modelType = {'Decentral','DecentralParticipation','DecentralParticipation','Decentral'};
        testResults = {'uratem','NILF','thetaHat','swagep','welfareratio'};

        opts.testGroup = 'PaperDecompositionExperimentMWCalibBase';
        opts.testBaseName = 'Calibrated';
        opts.testInitState = 'Calibrated';

        MainFindingsAverages_Wrapper(params, order, opts, moments, modelNames, modelPaths, modelType, testResults);
        opts = rmfield(opts,'testBaseName');

        modelNames = {'Laissez-faire','Optimal\\\\Participation','UI\\\\Participation ($\\hat{p}=b+x^{*}$)','Optimal\\\\UI'};
        modelPaths = {'LaissezFaireDecompPolicies','OptimalDecompParticipation','OptimalDecompParticipationUI','OptimalDecompPoliciesUI'};
        modelType = {'Decentral','DecentralParticipation','DecentralParticipation','UIDecentral'};
        testResults = {'uratem','NILF','thetaHat','swagep','welfareratio'};

        opts.testGroup = 'PaperDecompositionExperimentUI';
        opts.testBaseName = 'Laissez-faire';
        opts.testInitState = 'Laissez-faire';

        MainFindingsAverages_Wrapper(params, order, opts, moments, modelNames, modelPaths, modelType, testResults);
        opts = rmfield(opts,'testBaseName');


        modelNames = {'Calibrated','Optimal\\\\Participation','UI\\\\Participation ($\\hat{p}=b+x^{*}$)','Optimal\\\\UI'};
        modelPaths = {'CalibDecompPolicies','OptimalDecompParticipation','OptimalDecompParticipationUI','OptimalDecompPoliciesUI'};
        modelType = {'Decentral','DecentralParticipation','DecentralParticipation','UIDecentral'};
        testResults = {'uratem','NILF','thetaHat','swagep','welfareratio'};

        opts.testGroup = 'PaperDecompositionExperimentUICalibBase';
        opts.testBaseName = 'Calibrated';
        opts.testInitState = 'Calibrated';

        MainFindingsAverages_Wrapper(params, order, opts, moments, modelNames, modelPaths, modelType, testResults);
        opts = rmfield(opts,'testBaseName');

    end

    if opts.CompPolicyExperiments == 'y'
        modelNames = {'Calibrated\\\\economy','Planners\\\\optimum','Optimal\\\\min. wage','Optimal\\\\UI'};
        modelPaths = {'Calibrated','Planner','OptimalMW','OptimalUI'};
        modelType = {'Calib','Planner','Decentral','UIDecentral'};
        testResults = {'uratem','NILF','thetaHat','swagep','spikem','welfareratio'};

        opts.testGroup = 'CompPoliciesPlannerBase';
        opts.testBaseName = 'Planners\\\\optimum';
        opts.testInitState = 'Planners\\\\optimum';

        MainFindingsAverages_Wrapper(params, order, opts, moments, modelNames, modelPaths, modelType, testResults);
        opts = rmfield(opts,'testBaseName');

        modelNames = {'Calibrated\\\\economy','Planners\\\\optimum','Optimal\\\\min. wage','Optimal\\\\UI'};
        modelPaths = {'Calibrated','Planner','OptimalMW','OptimalUI'};
        modelType = {'Calib','Planner','Decentral','UIDecentral'};
        testResults = {'uratem','NILF','thetaHat','swagep','spikem','welfareratio'};

        opts.testGroup = 'CompPoliciesCalibBase';
        opts.testBaseName = 'Calibrated\\\\economy';
        opts.testInitState = 'Calibrated\\\\economy';

        MainFindingsAverages_Wrapper(params, order, opts, moments, modelNames, modelPaths, modelType, testResults);
        opts = rmfield(opts,'testBaseName');

        modelNames = {'Laissez-faire','Calibrated\\\\economy','Planners\\\\optimum','Optimal\\\\min. wage','Optimal\\\\UI'};
        modelPaths = {'LaissezFaire','Calibrated','Planner','OptimalMW','OptimalUI'};
        modelType = {'Decentral','Calib','Planner','Decentral','UIDecentral'};
        testResults = {'uratem','NILF','thetaHat','swagep','spikem','welfareratio'};

        opts.testGroup = 'CompPoliciesLaissezFaireBase';
        opts.testBaseName = 'Laissez-faire';
        opts.testInitState = 'Laissez-faire';

        MainFindingsAverages_Wrapper(params, order, opts, moments, modelNames, modelPaths, modelType, testResults);
        opts = rmfield(opts,'testBaseName');

        modelNames = {'Laissez-faire','Calibrated\\\\economy','Planners\\\\optimum','Optimal\\\\min. wage','Optimal\\\\UI','Both\\\\Optimal'};
        modelPaths = {'LaissezFaire','Calibrated','Planner','OptimalMW','OptimalUI','OptimalDecompPoliciesBoth'};
        modelType = {'Decentral','Calib','Planner','Decentral','UIDecentral','DecentralBoth'};
        testResults = {'uratem','NILF','thetaHat','swagep','spikem','welfareratio'};

        opts.testGroup = 'CompPoliciesPlusLaissezFaireBase';
        opts.testBaseName = 'Laissez-faire';
        opts.testInitState = 'Laissez-faire';

        MainFindingsAverages_Wrapper(params, order, opts, moments, modelNames, modelPaths, modelType, testResults);
        opts = rmfield(opts,'testBaseName');

        modelNames = {'Laissez-faire','Calibrated\\\\economy','Planners\\\\optimum','Optimal\\\\min. wage','Optimal\\\\UI','Opt. min. wage\\\\plus vac. subs.','Opt. UI\\\\plus vac. subs.'};
        modelPaths = {'LaissezFaire','Calibrated','Planner','OptimalMW','OptimalUI','OptimalDecompPoliciesVacMW','OptimalDecompPoliciesVacUI'};
        modelType = {'Decentral','Calib','Planner','Decentral','UIDecentral','DecentralVac','DecentralVac'};
        testResults = {'uratem','NILF','thetaHat','swagep','spikem','welfareratio'};

        opts.testGroup = 'CompPoliciesAllLaissezFaireBase';
        opts.testBaseName = 'Laissez-faire';
        opts.testInitState = 'Laissez-faire';

        MainFindingsAverages_Wrapper(params, order, opts, moments, modelNames, modelPaths, modelType, testResults);
        opts = rmfield(opts,'testBaseName');

    end

    if opts.SaveEstimOutput == 'y'
        opts.testGroup = 'Baseline';

        MainFindingsEstimResults_Wrapper(params, order, opts, moments, resultsSeries);

    end

end
