function ResultsVec = MainFindingsAverages(initThetaHat, thetaHat, initWbarHat, wbarHat, initzHat, zHat, params, order, moments, opts, modelType)
%%SMM m-file for Labor Market Participation and the Minimum Wage
%Author: Adrian Masters and Ben Griffy
%Date: July 2020

opts.test = 'n';

[pphi,eeta,bbeta,a,z,r,llambda,m,mmu,ssigma,lb,ub,pphiDelt,zDelt,wbarDelt,wbinDelt,N,T,wbar,mFun,dmFun,wageFun,pFun,udotFun] = Parameters(params, order, opts);

if strcmpi(modelType,'UIDecentral')


    % Matching rate and matching rate derivative
    initMatRate = mFun(initThetaHat);
    initDmatRate = dmFun(initThetaHat);


    % outcome calculations
    initUratem = llambda/(initMatRate+llambda);    % unemployment rate u/(u+e)

    % matching rate at theta* and derivative of matching function at theta*
    matRate = mFun(thetaHat);
    dmatRate = dmFun(thetaHat);

    unempRateMat = (((((llambda+matRate).*initUratem-llambda)*ones(1,T.Trans+1)).*exp(-(llambda+matRate)*linspace(0,T.TransMax,T.Trans+1))+llambda)./(llambda+matRate)).';
    unempRateMat = (1 - logncdf(zHat,mmu,ssigma)).*unempRateMat;

    NILFRateMat = zeros(T.Trans+1,1);
    NILFRateMat = repmat(logncdf(zHat,mmu,ssigma),T.Trans+1,1);


    empRateMat = zeros(T.Trans+1,1);
    empRateMat=(1-unempRateMat-NILFRateMat); % emplyment as share of totsal population


    % convenient definitions
    rl=r+llambda;
    rlm=r+llambda+matRate;
    lm=llambda+matRate;
    rlbm=r+llambda+bbeta*matRate;

    % outcome calculations
    uratem=llambda/(matRate+llambda);    % unemployment rate u/(u+e)

    NILF=logncdf(zHat,mmu,ssigma);   % share of poulation excluded from market

    empRate=(1-NILF)*(1-uratem); % emplyment as share of totsal population
    unempRate=1-empRate-NILF;

    % define new objects to limit line length
    rl=r+llambda;
    rlm=r+llambda+matRate;
    lm=llambda+matRate;
    rm=r+matRate;
    rlbm=r+llambda+bbeta*matRate;

    DENps=(bbeta*rlm)+(1-bbeta)*rl*pphi;

    % obtains psquigle the upper bound on productivity receiving the minimum wage

    spikem=(logncdf(zHat,mmu,ssigma)-NILF)/(1-NILF);

    Fbar=logncdf(zHat,mmu,ssigma);  % cum dist vlaue at wbar
    Fsq=logncdf(zHat,mmu,ssigma);  % cum dist as psquigle

    Ebar=LNCalcExp(params,order,opts,zHat,inf);    % expected prod above wbar
    Esq=LNCalcExp(params,order,opts,zHat,inf);    % expected prod above psquigle

    tempProdDraws = lognrnd(mmu,ssigma,[10000,1]);
    tempProdDraws(tempProdDraws<zHat) = [];


    AveLnW = nanmean(log(wageFun(tempProdDraws,thetaHat,0)));
    SDLnW = std(log(wageFun(tempProdDraws,thetaHat,0)),'omitnan');

    welfNILF = repmat((zHat+(z-zHat)).*logncdf(zHat,mmu,ssigma),T.Trans+1,1);

    welfUnemp = unempRateMat.*(zHat+(z-zHat));

    welfEmp = (empRateMat./(1 - logncdf(zHat,mmu,ssigma))).*integral(@(x)(x.*lognpdf(x,mmu,ssigma)),zHat,inf);

    welfVac = -thetaHat.*unempRateMat.*a;

    welfVec = exp(-r.*linspace(0,T.TransMax,T.Trans+1).').*(welfNILF + welfUnemp + welfEmp + welfVac);

    % averaged welfare

    welfare = (2*sum(welfVec)-welfVec(1)-welfVec(end))*(T.TransMax./T.Trans)./2 + welfVec(end)./r;

    swagep=zHat;  % obtains wage for ability level p

    modalm=exp(mmu-ssigma^2);
elseif strcmpi(modelType,'Planner') || strcmpi(modelType,'DecentralParticipation') || strcmpi(modelType,'DecentralVac')

    initPbarHat = initWbarHat;
    pbarHat = wbarHat;

    % Matching rate and matching rate derivative
    initMatRate = mFun(initThetaHat);
    initDmatRate = dmFun(initThetaHat);


    % outcome calculations
    initUratem = llambda/(initMatRate+llambda);    % unemployment rate u/(u+e)

    matRate = mFun(thetaHat);
    dmatRate = dmFun(thetaHat);

    % unempRateMat = (((((llambda+matRate).*initUratem-llambda)*ones(1,T.Trans)).*exp(-(llambda+matRate)*linspace(0,T.Trans-1,T.Trans))+llambda)./(llambda+matRate)).';
    unempRateMat = (((((llambda+matRate).*initUratem-llambda)).*exp(-(llambda+matRate)*linspace(0,T.TransMax,T.Trans+1))+llambda)./(llambda+matRate)).';
    unempRateMat = (1 - logncdf(pbarHat,mmu,ssigma)).*unempRateMat;

    NILFRateMat = zeros(T.Trans+1,1);
    NILFRateMat = repmat(logncdf(pbarHat,mmu,ssigma),T.Trans+1,1);


    empRateMat = zeros(T.Trans+1,1);
    % empRateMat=(1-NILFRateMat).*(1-unempRateMat); % emplyment as share of totsal population
    empRateMat=(1-unempRateMat-NILFRateMat); % emplyment as share of totsal population


    % outcome calculations
    uratem=llambda/(matRate+llambda);    % unemployment rate u/(u+e)

    NILF=logncdf(pbarHat,mmu,ssigma);   % share of poulation excluded from market

    empRate=(1-NILF)*(1-uratem); % emplyment as share of totsal population
    unempRate=1-empRate-NILF;

    % define new objects to limit line length
    rl=r+llambda;
    rlm=r+llambda+matRate;
    lm=llambda+matRate;
    rm=r+matRate;
    rlbm=r+llambda+bbeta*matRate;

    DENps=(bbeta*rlm)+(1-bbeta)*rl*pphi;

    % obtains psquigle the upper bound on productivity receiving the minimum wage



    spikem=(logncdf(pbarHat,mmu,ssigma)-NILF)/(1-NILF);

    Fbar=logncdf(pbarHat,mmu,ssigma);  % cum dist vlaue at wbar
    Fsq=logncdf(pbarHat,mmu,ssigma);  % cum dist as psquigle

    Ebar=LNCalcExp(params,order,opts,pbarHat,inf);    % expected prod above wbar
    Esq=LNCalcExp(params,order,opts,pbarHat,inf);    % expected prod above psquigle

    tempProdDraws = lognrnd(mmu,ssigma,[10000,1]);
    tempProdDraws(tempProdDraws<pbarHat) = [];


    AveLnW = nanmean(log(wageFun(tempProdDraws,thetaHat,0)));
    SDLnW = std(log(wageFun(tempProdDraws,thetaHat,0)),'omitnan');

    % integral of \phi*x + \bar{b} from 0 to \bar{w}
    % welfNILF = repmat(integral(@(x)((zHat+(z-zHat)+pphi.*x).*lognpdf(x,mmu,ssigma)),0,pbarHat),T.Trans,1);
    welfNILF = repmat((zHat+(z-zHat)).*logncdf(pbarHat,mmu,ssigma),T.Trans+1,1);

    % unemp rate/(1 - P(w<=\bar{w})) times integral of \phi*x + \bar{b} from \bar{w} to \bar{p}, in this case \bar{b}=\inf
    welfUnemp = unempRateMat.*(zHat+(z-zHat));

    % (1 - P(w<=\bar{w}) - unemp rate)/(1 - P(w<=\bar{w})) times integral of \phi*x + \bar{b} from \bar{w} to \bar{p}, in this case \bar{b}=\inf
    welfEmp = (empRateMat./(1 - logncdf(pbarHat,mmu,ssigma))).*integral(@(x)(x.*lognpdf(x,mmu,ssigma)),pbarHat,inf);

    % number of vacancies times vacancy creation cost
    welfVac = -thetaHat.*unempRateMat.*a;

    % total welfare. All components are static, so either calculation will work for the ratio.
    welfVec = exp(-r.*linspace(0,T.TransMax,T.Trans+1).').*(welfNILF + welfUnemp + welfEmp + welfVac);

    % averaged welfare
    welfare = (2*sum(welfVec)-welfVec(1)-welfVec(end))*(T.TransMax./T.Trans)./2 + welfVec(end)./r;

    swagep=pbarHat;  % obtains wage for ability level p

    modalm=exp(mmu-ssigma^2);
else

    % Matching rate and matching rate derivative
    initMatRate = mFun(initThetaHat);
    initDmatRate = dmFun(initThetaHat);


    % outcome calculations
    initUratem = llambda/(initMatRate+llambda);    % unemployment rate u/(u+e)

    matRate = mFun(thetaHat);
    dmatRate = dmFun(thetaHat);

    unempRateMat = (((((llambda+matRate).*initUratem-llambda)*ones(1,T.Trans+1)).*exp(-(llambda+matRate)*linspace(0,T.TransMax,T.Trans+1))+llambda)./(llambda+matRate)).';
    unempRateMat = (1 - logncdf(wbarHat,mmu,ssigma)).*unempRateMat;


    NILFRateMat = zeros(T.Trans+1,1);
    NILFRateMat = repmat(logncdf(wbarHat,mmu,ssigma),T.Trans+1,1);


    empRateMat = zeros(T.Trans+1,1);
    empRateMat=(1-unempRateMat-NILFRateMat); % emplyment as share of totsal population

    uratem=llambda/(matRate+llambda);    % unemployment rate u/(u+e)

    NILF=logncdf(wbarHat,mmu,ssigma);   % share of poulation excluded from market

    empRate=(1-NILF)*(1-uratem); % emplyment as share of totsal population
    unempRate=1-empRate-NILF;

    % define new objects to limit line length
    rl=r+llambda;
    rlm=r+llambda+matRate;
    lm=llambda+matRate;
    rm=r+matRate;
    rlbm=r+llambda+bbeta*matRate;

    DENps=(bbeta*rlm)+(1-bbeta)*rl*pphi;

    % obtains psquigle the upper bound on productivity receiving the minimum wage

    ps=(rlbm*wbarHat-(1-bbeta)*rl*zHat)/DENps;

    spikem=(logncdf(ps,mmu,ssigma)-NILF)/(1-NILF);

    Fbar=logncdf(wbarHat,mmu,ssigma);  % cum dist vlaue at wbar
    Fsq=logncdf(ps,mmu,ssigma);  % cum dist as psquigle

    Ebar=LNCalcExp(params,order,opts,wbarHat,inf);    % expected prod above wbar
    Esq=LNCalcExp(params,order,opts,ps,inf);    % expected prod above psquigle

    tempProdDraws = lognrnd(mmu,ssigma,[10000,1]);
    tempProdDraws(tempProdDraws<wbarHat) = [];


    AveLnW = nanmean(log(wageFun(tempProdDraws,thetaHat,wbarHat)));
    SDLnW = std(log(wageFun(tempProdDraws,thetaHat,wbarHat)),'omitnan');

    welfNILF = repmat((zHat+(z-zHat)).*logncdf(wbarHat,mmu,ssigma),T.Trans+1,1);

    % unemp rate/(1 - P(w<=\bar{w})) times integral of \phi*x + \bar{b} from \bar{w} to \bar{p}, in this case \bar{b}=\inf
    welfUnemp = unempRateMat.*(zHat+(z-zHat));

    % (1 - P(w<=\bar{w}) - unemp rate)/(1 - P(w<=\bar{w})) times integral of \phi*x + \bar{b} from \bar{w} to \bar{p}, in this case \bar{b}=\inf
    welfEmp = (empRateMat./(1 - logncdf(wbarHat,mmu,ssigma))).*integral(@(x)(x.*lognpdf(x,mmu,ssigma)),wbarHat,inf);

    % number of vacancies times vacancy creation cost
    welfVac = -thetaHat.*unempRateMat.*a;

    % total welfare. All components are static, so either calculation will work for the ratio.
    welfVec = exp(-r.*linspace(0,T.TransMax,T.Trans+1).').*(welfNILF + welfUnemp + welfEmp + welfVac);

    % averaged welfare
    welfare = (2*sum(welfVec)-welfVec(1)-welfVec(end))*(T.TransMax./T.Trans)./2 + welfVec(end)./r

    swagep=(DENps*ps+(1-bbeta)*rl*zHat)/rlbm;  % obtains wage for ability level p

    modalm=exp(mmu-ssigma^2);
end

ResultsVec = [uratem;NILF;empRate;AveLnW;SDLnW;Fbar;Fsq;Ebar;Esq;swagep;spikem;modalm;wbarHat;thetaHat;welfare];

end
