function MainFindingsAverages_Wrapper(params, order, opts, moments, modelNames, modelPaths, modelType, testResults)
%% II m-file for Wealth Effects, Search, and Life-Cycle Earnings Inequality
% solve and simulate model given a set of parameters and then calculate
% distance

[pphi,eeta,bbeta,a,z,r,llambda,m,mmu,ssigma,lb,ub,pphiDelt,zDelt,wbarDelt,wbinDelt,N,T,wbar,mFun,dmFun,wageFun,pFun,udotFun] = Parameters(params, order, opts);

ResultsShort = {'uratem','NILF','empRate','AveLnW','SDLnW','Fbar','Fsq','Ebar','Esq','swagep','spikem','modalm','wbarHat','thetaHat','welfare'};

ResultsNames = {'Unemp.\\\\Rate','Non-Part.\\\\Rate','Emp.\\\\Rate','$E[ln(w)]$','$SD[ln(w)]$','Fbar','Fsq','Ebar','Esq','Ability\\\\Threshold (\\$)','$P(w=\\bar{w})$','Modal\\\\Wage','$\\bar{w}$','$\\theta$','Welfare'};

if opts.CalcTrans == 'y'
    if isfield(opts,'testInitState')
        baseInd = find(strcmp(modelNames,opts.testInitState));
    else
        baseInd = 1;
    end
    matfile = fullfile(pwd,'/output/',modelPaths{baseInd},sprintf('solution%s.mat',modelType{baseInd}));
    load(matfile);
    if strcmpi(modelType{baseInd},'Planner')
        initWbarHat = pbarHat;
        initzHat = z;
    elseif strcmpi(modelType{baseInd},'UIDecentral')
        initWbarHat = max(wbar,zHat);
        initzHat = zHat;
    else
        initzHat = z;
        initWbarHat = wbarHat;
    end
    initThetaHat = thetaHat;
    clear pbarHat zHat wbarHat thetaHat;
end
    ResultsVec = zeros(length(ResultsShort),length(modelNames));
    vacSubsVec = zeros(1,length(modelNames));
    for i = 1:length(modelNames)

        matfile = fullfile(pwd,'/output/',modelPaths{i},sprintf('solution%s.mat',modelType{i}));
        load(matfile);
        if strcmpi(modelType{i},'Planner')
            wbarHat = pbarHat;
            zHat = z;
        elseif strcmpi(modelType{i},'UIDecentral')
            wbarHat = max(wbar,zHat);
        elseif strcmpi(modelType{i},'DecentralBoth')
            wbarHatTemp = wbarHat;
            wbarHat = max(wbarHat,zHat);
        elseif strcmpi(modelType{i},'DecentralVac')
            wbarHat = pbarHat;
            zHat = z;
            vacSubsVec(i) = vacSubs;
        elseif strcmpi(modelType{i},'DecentralAll')
            wbarHatTemp = wbarHat;
            wbarHat = max(wbarHat,zHat);
        else
            zHat = z;
        end
        if opts.CalcTrans == 'y'
            ResultsVec(:,i) = MainFindingsAverages(initThetaHat, thetaHat, initWbarHat, wbarHat, initzHat, zHat, params, order, moments, opts, modelType{i});
        else
            ResultsVec(:,i) = MainFindingsAverages(thetaHat, thetaHat, wbarHat, wbarHat, zHat, zHat, params, order, moments, opts, modelType{i});
        end
    end


if any(strcmp(testResults, 'welfareratio'))
    if isfield(opts,'testBaseName')
        baseName = opts.testBaseName;
    elseif any(strcmpi(modelNames,'Planner'))
        baseName = 'Planner';
    else
        baseName = modelNames{1};
    end
    ResultsVec = cat(1,ResultsVec,zeros(1,length(modelNames)));
    ResultsShort{end+1} = 'welfareratio';
    ResultsNames{end+1} = sprintf('%s(%s of %s)','Welfare Ratio\\\\','\\%%',baseName);
    for i = 1:length(modelNames)
        if ~strcmpi(modelNames{i},baseName)
            ResultsVec(strcmp(ResultsShort, 'welfareratio'),i) = 100*(ResultsVec(strcmp(ResultsShort, 'welfare'),i)./ResultsVec(strcmp(ResultsShort, 'welfare'),strcmp(modelNames, baseName)));
        end
    end
    ResultsVec(strcmp(ResultsShort, 'welfareratio'),strcmp(modelNames, baseName)) = 100;
end


if ~isequal(exist(fullfile(pwd,opts.results_path,opts.testGroup),'dir'),7)
    mkdir(fullfile(pwd,opts.results_path,opts.testGroup));
end


FID = fopen(fullfile(pwd,opts.results_path,opts.testGroup,sprintf('ModelAverages%s_Vert.tex',opts.testGroup)),'w');
fprintf(FID, '\\begin{tabular}');
fprintf(FID, '{|');
for j = 1:(length(testResults)+1)
    fprintf(FID, sprintf('%s','c'));
end
fprintf(FID, '|}');
fprintf(FID, '\\hline\n');
fprintf(FID, '& ');
for j = 1:(length(testResults)-1)
    fprintf(FID, '\\specialcell{');
    fprintf(FID, sprintf('%s',ResultsNames{find(strcmp(ResultsShort, testResults{j}))}));
    fprintf(FID, '} &');
end
fprintf(FID, '\\specialcell{');
fprintf(FID, sprintf('%s',ResultsNames{find(strcmp(ResultsShort, testResults{end}))}));
fprintf(FID, '}');
fprintf(FID, '\\\\\\hline\n');
for i = 1:size(ResultsVec,2)
    if ~strcmpi(modelType{i},'DecentralVac')
        fprintf(FID, '\\specialcell{');
        fprintf(FID,sprintf('%s',modelNames{i}))
        fprintf(FID, '} &');
        for j = 1:(length(testResults)-1)
            fprintf(FID, '%8.3f & ', ResultsVec(find(strcmp(ResultsShort, testResults{j})),i));
        end
        fprintf(FID, '%8.3f \\\\', ResultsVec(find(strcmp(ResultsShort, testResults{end})),i));
        % fprintf(FID, '\\hline ');
    end
    if i==size(ResultsVec,2)
        fprintf(FID, '\\hline ');
    end
    fprintf(FID,'\n');
end

fprintf(FID, '\\end{tabular}\n');
fclose(FID);


FID = fopen(fullfile(pwd,opts.results_path,opts.testGroup,sprintf('ModelAverages%s_Horz.tex',opts.testGroup)),'w');
fprintf(FID, '\\begin{tabular}');
fprintf(FID, '{|');
for j = 1:(size(ResultsVec,2)+1)
    fprintf(FID, sprintf('%s','r'));
end
fprintf(FID, '|}');
fprintf(FID, '\\hline\n');
fprintf(FID, '& ');
for j = 1:(size(ResultsVec,2)-1)
    fprintf(FID, sprintf('\\specialcell\{%s\} &',modelNames{j}));
end
fprintf(FID, sprintf('\\specialcell\{%s\}',modelNames{end}));
fprintf(FID, '\\\\\\hline\n');
for i = 1:length(testResults)
    fprintf(FID,sprintf('%s &',ResultsNames{find(strcmp(ResultsShort, testResults{i}))}))
    for j = 1:(size(ResultsVec,2)-1)
        fprintf(FID, '%8.3f & ', ResultsVec(find(strcmp(ResultsShort, testResults{i})),j));
    end
    fprintf(FID, '%8.3f \\\\', ResultsVec(find(strcmp(ResultsShort, testResults{i})),end));
    if i==length(testResults)
        fprintf(FID, '\\hline ');
    end
    fprintf(FID,'\n');
end

fprintf(FID, '\\end{tabular}\n');
fclose(FID);


if any(strcmp(modelType, 'DecentralVac'))

    indVec = find(strcmpi(modelType,'DecentralVac'));


    FID = fopen(fullfile(pwd,opts.results_path,opts.testGroup,sprintf('ModelAveragesVac%s_Horz.tex',opts.testGroup)),'w');
    fprintf(FID, '\\begin{tabular}');
    fprintf(FID, '{|');
    for j = 1:length(indVec)+1
        fprintf(FID, sprintf('%s','r'));
    end
    fprintf(FID, '|}');
    fprintf(FID, '\\hline\n');
    fprintf(FID, '& ');
    for ind = 1:size(indVec,2)-1
        fprintf(FID, '\\specialcell');
        fprintf(FID, '{');
        fprintf(FID, sprintf('%s',modelNames{indVec(ind)}));
        fprintf(FID, '} &');
    end
    fprintf(FID, '\\specialcell');
    fprintf(FID, '{');
    fprintf(FID, sprintf('%s',modelNames{indVec(end)}));
    fprintf(FID, '}');
    fprintf(FID, '\\\\\\hline\n');
    fprintf(FID,sprintf('%s &','Vacancy Subsidy'));
    for ind = 1:length(indVec)-1
        j = indVec(ind);
        fprintf(FID, '%8.3f & ', vacSubsVec(j));
    end
    fprintf(FID, '%8.3f \\\\', vacSubsVec(indVec(end)));
    fprintf(FID, '\\hline ');
    fprintf(FID,'\n');

    fprintf(FID, '\\end{tabular}\n');
    fclose(FID);
end

end
