function [MomentsVec,ResultsVec] = MainFindingsEstimResults(params, order, opts)
%%SMM m-file for Labor Market Participation and the Minimum Wage
%Author: Adrian Masters and Ben Griffy
%Date: July 2020


opts.test = 'n';

[pphi,eeta,bbeta,a,z,r,llambda,m,mmu,ssigma,lb,ub,pphiDelt,zDelt,wbarDelt,wbinDelt,N,T,wbar,mFun,dmFun,wageFun,pFun,udotFun] = Parameters(params, order, opts);

% Solve model to obtain market tightness

solveOpts.prob = 'calib';
err = ModelMaxWelf_Wrapper(params, order, opts, [], [], solveOpts);

% Calculate moments given market tightness

% load market tightness
matfile = fullfile(pwd,opts.output_path,'solutionCalib.mat');
load(matfile);

% Matching rate and matching rate derivative
matRate = mFun(thetaHat);
dmatRate = dmFun(thetaHat);

% outcome calculations
uratem=llambda/(matRate+llambda);    % unemployment rate u/(u+e)

NILF=logncdf(wbar,mmu,ssigma);   % share of poulation excluded from market

empRate=(1-NILF)*(1-uratem); % emplyment as share of totsal population

% define new objects to limit line length
rl=r+llambda;
rlm=r+llambda+matRate;
lm=llambda+matRate;
rm=r+matRate;
rlbm=r+llambda+bbeta*matRate;

DENps=(bbeta*rlm)+(1-bbeta)*rl*pphi;

% obtains psquigle the upper bound on productivity receiving the minimum wage
ps=(rlbm*wbar-(1-bbeta)*rl*z)/DENps;

% Fbar=logncdf(wbarHat,mmu,ssigma);  % cum dist vlaue at wbar
% Fsq=logncdf(ps,mmu,ssigma);  % cum dist as psquigle

% Spike at minimum wage
spikem=(logncdf(ps,mmu,ssigma)-NILF)/(1-NILF);

tempProdDraws = lognrnd(mmu,ssigma,[10000,1]);
tempProdDraws(tempProdDraws<wbar) = [];
% tempProdDraws(wageFun(tempProdDraws,thetaHat,wbar)>=30.5) = [];

AveLnW = nanmean(log(wageFun(tempProdDraws,thetaHat,wbar)));
SDLnW = std(log(wageFun(tempProdDraws,thetaHat,wbar)),'omitnan');

% modalm=wageFun(exp(mmu-ssigma^2),thetaHat,wbar);

initUratem = uratem;

modalm=exp(AveLnW-SDLnW^2);

empVec = zeros(N.Elast,1);
mwVec = linspace(wbar-wbarDelt,wbar+wbarDelt,N.Elast).';

for i = 1:N.Elast
    solveOpts.prob = 'decentralfixed';
    options = optimoptions('fsolve','Display','none','Diagnostics','off');
    obj_fun = @(theta)Model([theta; mwVec(i)],params,order,opts,solveOpts);
    xmin=fsolve(obj_fun,thetaHat,options);  % may need to change starting values depanding on b and phi

    tempthetaHat = xmin;

    tempmatRate = mFun(tempthetaHat);

    unempRateMat = (((((llambda+tempmatRate).*initUratem-llambda)).*exp(-(llambda+tempmatRate)*linspace(0,T.TransMax,T.Trans+1))+llambda)./(llambda+tempmatRate)).';
    unempRateMat = (1 - logncdf(wbarHat,mmu,ssigma)).*unempRateMat;


    % NILFRateMat = zeros(T.Trans+1,1);
    % NILFRateMat(1) = logncdf(initWbarHat,mmu,ssigma);
    % NILFRateMat(2:end) = logncdf(wbarHat,mmu,ssigma);
    NILFRateMat = repmat(logncdf(mwVec(i),mmu,ssigma),T.Trans+1,1);


    % empRateMat = zeros(T.Trans+1,1);
    empRateMat=(1-unempRateMat-NILFRateMat); % emplyment as share of totsal population
    % empRateMat(1) = 1 - (1 - logncdf(initWbarHat,mmu,ssigma))*(1 - initUratem) -  logncdf(initWbarHat,mmu,ssigma);


    % tempNILF=logncdf(mwVec(i),mmu,ssigma);   % share of poulation excluded from market

    % empVec(i) = nanmean(empRateMat);
    empVec(i) = empRateMat(end);
    clear NILFRateMat unempRateMat empRateMat;

    % empVec(i)=(1-tempNILF)*(1-tempuratem); % emplyment as share of totsal population
                                           % empVec(i)=(1-tempuratem); % emplyment as share of totsal population
end

betaests = regress(log(empVec),[ones(size(mwVec)), log(mwVec)]);

mwelast = betaests(2);

MomentsVec = [uratem, NILF, AveLnW, SDLnW, spikem];

ResultsVec = [mwelast;modalm;matRate];

end
