function MainFindingsEstimResults_Wrapper(params, order, opts, moments, ResultsSeries)
%% MainFindingsEstimResults_Wrapper.m file for "Participation and Labor Market Policy"
% solve and simulate model given a set of parameters and then calculate
% distance

[pphi,eeta,bbeta,a,z,r,llambda,m,mmu,ssigma,lb,ub,pphiDelt,zDelt,wbarDelt,wbinDelt,N,T,wbar,mFun,dmFun,wageFun,pFun,udotFun] = Parameters(params, order, opts);

NonTargeted = ResultsSeries.NonTargeted;
wageDistData = ResultsSeries.empWageDist(:,2);
xAxisData = ResultsSeries.empWageDist(:,1);

[~,tempInd] = max(wageDistData);

modalw = xAxisData(tempInd);

PaperParams = {'bbeta','mmu','ssigma','z','a','eeta','r','llambda','m','wbar'};

ParamNames = {'$\\beta$','$\\mu$','$\\sigma$','$\\bar{b}$','$a$','$\\eta$','$r$','$\\lambda$','$\\bar{m}$','$\\bar{w}$'};

ParamComment = {'Barg. Power','Mean of Prod. Dist','Var. of Prod. Dist','Non-Market Util.','Vacancy Cost','Matching Elast.','Discount Rate','Sep. Rate','Matching Fun. Norm.','Min. Wage'};

MomentNames = {'Unemp. Rate','Non-Part. Rate','$E[ln(w)]$','$SD[ln(w)]$','$P(w=\\bar{w})$'};

MomentComment = {'','','','',''};

NonTargetedNames = {'Min. wage elasticity','Modal wage','Monthly job-finding rate'};

NonTargetedComment = {'From \\citet{keil2001minimum}','CPS, 2012-2014','From \\citet{Shimer2004}'};

NonTargeted(strcmp(NonTargetedNames,'Modal Wage')) = modalw;

[MomentsVec,NonTargetedVec] = MainFindingsEstimResults(params, order, opts);

if ~isequal(exist(fullfile(pwd,opts.results_path,opts.testGroup),'dir'),7)
    mkdir(fullfile(pwd,opts.results_path,opts.testGroup));
end

matfile = fullfile(pwd,opts.output_path,'solutionCalib.mat');
load(matfile);

xAxis = cat(1,7.5,xAxisData);
wageDistModel = zeros(size(xAxis,1)-1,100);

for i = 1:100
    tempProdDraws = lognrnd(mmu,ssigma,[10000,1]);
    tempProdDraws(tempProdDraws<7.5) = [];
    tempProdDraws(wageFun(tempProdDraws,thetaHat,wbar)>=30.5) = [];

    wageDataModel = wageFun(tempProdDraws,thetaHat,wbar);
    % xAxis = linspace(7.5,30,size(xAxisData,1));

    [wageDistModel(:,i),edges] = histcounts(wageDataModel,xAxis);

    wageDistModel(:,i) = wageDistModel(:,i)./sum(wageDistModel(:,i));
end

wageDistModel = nanmean(wageDistModel,2);

f01=figure('name','LRInc_compare');
% hold on;
p1 = plot(xAxisData',wageDistModel,'color','red','LineStyle','-','LineWidth',2);
hold on
p2 = bar(xAxisData',wageDistData,'FaceColor','blue','EdgeColor','blue','FaceAlpha',0.6,'EdgeAlpha',0.6);
alpha(0.25)
xlabel('Hourly Wage')
ylabel('Prob.')
myfiguresize=[0,0,4,4];
set(gcf, 'PaperPosition', myfiguresize);

set(gca, ...
    'GridLineStyle'         , '--'     , ...
    'Box'         , 'off'     , ...
    'TickDir'     , 'out'     , ...
    'TickLength'  , [.02 .02] , ...
    'XMinorTick'  , 'on'      , ...
    'YMinorTick'  , 'on'      , ...
    'XGrid'       , 'on'      , ...
    'YGrid'       , 'on'      , ...
    'XColor'      , [.3 .3 .3], ...
    'YColor'      , [.3 .3 .3], ...
    'LineWidth'   , 1         );
figfile = fullfile(pwd,opts.results_path,opts.testGroup,'WagePDF');
saveas(gcf,figfile,'png');
saveas(gcf,figfile,'epsc');
close;
hold off;


wageCDFData = cumsum(wageDistData);
wageCDFModel = cumsum(wageDistModel);

f01=figure('name','LRInc_compare');
% hold on;
p1 = plot(xAxisData',wageCDFModel,'color','red','LineStyle','-','LineWidth',2);
hold on
p2 = bar(xAxisData',wageCDFData,'FaceColor','blue','EdgeColor','blue','FaceAlpha',0.6,'EdgeAlpha',0.6);
alpha(0.25)
xlabel('Hourly Wage')
ylabel('Cum. Prob.')
myfiguresize=[0,0,4,4];
set(gcf, 'PaperPosition', myfiguresize);

set(gca, ...
    'GridLineStyle'         , '--'     , ...
    'Box'         , 'off'     , ...
    'TickDir'     , 'out'     , ...
    'TickLength'  , [.02 .02] , ...
    'XMinorTick'  , 'on'      , ...
    'YMinorTick'  , 'on'      , ...
    'XGrid'       , 'on'      , ...
    'YGrid'       , 'on'      , ...
    'XColor'      , [.3 .3 .3], ...
    'YColor'      , [.3 .3 .3], ...
    'LineWidth'   , 1         );
figfile = fullfile(pwd,opts.results_path,opts.testGroup,'WageCDF');
saveas(gcf,figfile,'png');
saveas(gcf,figfile,'epsc');
close;
hold off;


FID = fopen(fullfile(pwd,opts.results_path,opts.testGroup,'ModelMomentsVert.tex'),'w');
fprintf(FID, '\\begin{tabular}');
fprintf(FID, '{|');
fprintf(FID, 'r r r r');
fprintf(FID, '|}');
fprintf(FID, '\\hline\n');
fprintf(FID, 'Moment & Data & Model & Comment');
fprintf(FID, '\\\\\\hline\n');
for i = 1:length(MomentsVec)
    fprintf(FID,sprintf('%s &',MomentNames{i}));
    fprintf(FID, '%8.2f & %8.2f & ', moments(i), MomentsVec(i));
    fprintf(FID,sprintf('%s',MomentComment{i}));
    if i==length(MomentsVec)
        fprintf(FID, '\\\\\\hline ');
    else
        fprintf(FID, '\\\\');
    end
    fprintf(FID,'\n');
end

fprintf(FID, '\\end{tabular}\n');
fclose(FID);

FID = fopen(fullfile(pwd,opts.results_path,opts.testGroup,'ModelNonTargetedVert.tex'),'w');
fprintf(FID, '\\begin{tabular}');
fprintf(FID, '{|');
fprintf(FID, 'r r r r');
fprintf(FID, '|}');
fprintf(FID, '\\hline\n');
fprintf(FID, 'Moment & Data & Model & Comment');
fprintf(FID, '\\\\\\hline\n');
for i = 1:length(NonTargetedVec)
    fprintf(FID,sprintf('%s &',NonTargetedNames{i}));
    fprintf(FID, '%8.2f & %8.2f & ', NonTargeted(i), NonTargetedVec(i));
    fprintf(FID,sprintf('%s',NonTargetedComment{i}));
    if i==length(NonTargetedVec)
        fprintf(FID, '\\\\\\hline ');
    else
        fprintf(FID, '\\\\');
    end
    fprintf(FID,'\n');
end

fprintf(FID, '\\end{tabular}\n');
fclose(FID);


FID = fopen(fullfile(pwd,opts.results_path,opts.testGroup,'ModelMomentsVertNoComment.tex'),'w');
fprintf(FID, '\\begin{tabular}');
fprintf(FID, '{|');
fprintf(FID, 'r r r');
fprintf(FID, '|}');
fprintf(FID, '\\hline\n');
fprintf(FID, 'Moment & Data & Model');
fprintf(FID, '\\\\\\hline\n');
for i = 1:length(MomentsVec)
    fprintf(FID,sprintf('%s &',MomentNames{i}));
    fprintf(FID, '%8.2f & %8.2f', moments(i), MomentsVec(i));
    if i==length(MomentsVec)
        fprintf(FID, '\\\\\\hline ');
    else
        fprintf(FID, '\\\\');
    end
    fprintf(FID,'\n');
end

fprintf(FID, '\\end{tabular}\n');
fclose(FID);

FID = fopen(fullfile(pwd,opts.results_path,opts.testGroup,'ModelNonTargetedVertNoComment.tex'),'w');
fprintf(FID, '\\begin{tabular}');
fprintf(FID, '{|');
fprintf(FID, 'r r r');
fprintf(FID, '|}');
fprintf(FID, '\\hline\n');
fprintf(FID, 'Moment & Data & Model');
fprintf(FID, '\\\\\\hline\n');
for i = 1:length(NonTargetedVec)
    fprintf(FID,sprintf('%s &',NonTargetedNames{i}));
    fprintf(FID, '%8.2f & %8.2f', NonTargeted(i), NonTargetedVec(i));
    if i==length(NonTargetedVec)
        fprintf(FID, '\\\\\\hline ');
    else
        fprintf(FID, '\\\\');
    end
    fprintf(FID,'\n');
end

fprintf(FID, '\\end{tabular}\n');
fclose(FID);


FID = fopen(fullfile(pwd,opts.results_path,opts.testGroup,'ParameterValues.tex'),'w');
fprintf(FID, '\\begin{tabular}');
fprintf(FID, '{|');
for j = 1:(length(PaperParams)+1)
    fprintf(FID, sprintf('%s','r'));
end
fprintf(FID, '|}');
fprintf(FID, '\\hline\n');
fprintf(FID, '& ');
for j = 1:(length(PaperParams)-1)
    fprintf(FID, sprintf('%s &',ParamNames{j}));
end
fprintf(FID, sprintf('%s',ParamNames{end}));
fprintf(FID, '\\\\\\hline\n');
fprintf(FID, '& ');
for j = 1:(length(PaperParams)-1)
    fprintf(FID, sprintf('%s &',ParamComment{j}));
end
fprintf(FID, sprintf('%s',ParamComment{end}));
fprintf(FID, '\n');
fprintf(FID, '& ');
for j = 1:(length(PaperParams)-1)
    if params(find(strcmp(order, PaperParams{j}))) < 0.01
        fprintf(FID, '%8.4f & ', round(params(find(strcmp(order, PaperParams{j}))),4));
    elseif params(find(strcmp(order, PaperParams{j}))) < 1
        fprintf(FID, '%8.2f & ', round(params(find(strcmp(order, PaperParams{j}))),2));
    elseif params(find(strcmp(order, PaperParams{j}))) > 1 && rem(params(find(strcmp(order, PaperParams{j}))),1)==0
        fprintf(FID, '%8.0f & ', round(params(find(strcmp(order, PaperParams{j}))),0));
    else
        fprintf(FID, '%8.2f & ', round(params(find(strcmp(order, PaperParams{j}))),2));
    end
end
if params(find(strcmp(order, PaperParams{end}))) < 0.01
    fprintf(FID, '%8.4f', round(params(find(strcmp(order, PaperParams{end}))),4));
elseif params(find(strcmp(order, PaperParams{end}))) < 1
    fprintf(FID, '%8.2f', round(params(find(strcmp(order, PaperParams{end}))),2));
elseif params(find(strcmp(order, PaperParams{end}))) > 1 && rem(params(find(strcmp(order, PaperParams{end}))),1)==0
    fprintf(FID, '%8.0f', round(params(find(strcmp(order, PaperParams{end}))),0));
else
    fprintf(FID, '%8.2f', round(params(find(strcmp(order, PaperParams{end}))),2));
end
fprintf(FID, '\\\\\\hline ');
fprintf(FID,'\n');
fprintf(FID, '\\end{tabular}\n');
fclose(FID);

FID = fopen(fullfile(pwd,opts.results_path,opts.testGroup,'ParameterValuesVert.tex'),'w');
fprintf(FID, '\\begin{tabular}');
fprintf(FID, '{|');
fprintf(FID, 'r r r');
fprintf(FID, '|}');
fprintf(FID, '\\hline\n');
fprintf(FID, 'Parameter & Comment & Value');
fprintf(FID, '\\\\\\hline\n');
for i = 1:length(PaperParams)
    fprintf(FID,sprintf('%s & %s &',ParamNames{i},ParamComment{i}));
    if params(find(strcmp(order, PaperParams{i}))) < 0.01
        fprintf(FID, '%8.4f\\\\\n', round(params(find(strcmp(order, PaperParams{i}))),4));
    elseif params(find(strcmp(order, PaperParams{i}))) < 1
        fprintf(FID, '%8.2f\\\\\n', round(params(find(strcmp(order, PaperParams{i}))),2));
    elseif params(find(strcmp(order, PaperParams{i}))) > 1 && rem(params(find(strcmp(order, PaperParams{i}))),1)==0
        fprintf(FID, '%8.0f\\\\\n', round(params(find(strcmp(order, PaperParams{i}))),0));
    else
        fprintf(FID, '%8.2f\\\\\n', round(params(find(strcmp(order, PaperParams{i}))),2));
    end
    if i==length(PaperParams)
        fprintf(FID, '\\hline ');
    end
end

fprintf(FID, '\\end{tabular}\n');
fclose(FID);


FID = fopen(fullfile(pwd,opts.results_path,opts.testGroup,'PresetParameterValues.tex'),'w');
fprintf(FID, '\\begin{tabular}');
fprintf(FID, '{|');
for j = opts.nparams:length(PaperParams)-opts.nparams+1
    fprintf(FID, sprintf('%s','r'));
end
fprintf(FID, '|}');
fprintf(FID, '\\hline\n');
fprintf(FID, '& ');
for j = opts.nparams:length(PaperParams)-opts.nparams-1
    fprintf(FID, sprintf('%s &',ParamNames{j}));
end
fprintf(FID, sprintf('%s',ParamNames{end}));
fprintf(FID, '\\\\\\hline\n');
fprintf(FID, '& ');
for j = opts.nparams:length(PaperParams)-opts.nparams-1
    fprintf(FID, sprintf('%s &',ParamComment{j}));
end
fprintf(FID, sprintf('%s',ParamComment{end}));
fprintf(FID, '\n');
fprintf(FID, '& ');
for j = opts.nparams:length(PaperParams)-opts.nparams-1
    if params(find(strcmp(order, PaperParams{j}))) < 0.01
        fprintf(FID, '%8.4f & ', round(params(find(strcmp(order, PaperParams{j}))),4));
    elseif params(find(strcmp(order, PaperParams{j}))) < 1
        fprintf(FID, '%8.2f & ', round(params(find(strcmp(order, PaperParams{j}))),2));
    elseif params(find(strcmp(order, PaperParams{j}))) > 1 && rem(params(find(strcmp(order, PaperParams{j}))),1)==0
        fprintf(FID, '%8.0f & ', round(params(find(strcmp(order, PaperParams{j}))),0));
    else
        fprintf(FID, '%8.2f & ', round(params(find(strcmp(order, PaperParams{j}))),2));
    end
end
if params(find(strcmp(order, PaperParams{end}))) < 0.01
    fprintf(FID, '%8.4f', round(params(find(strcmp(order, PaperParams{end}))),4));
elseif params(find(strcmp(order, PaperParams{end}))) < 1
    fprintf(FID, '%8.2f', round(params(find(strcmp(order, PaperParams{end}))),2));
elseif params(find(strcmp(order, PaperParams{end}))) > 1 && rem(params(find(strcmp(order, PaperParams{end}))),1)==0
    fprintf(FID, '%8.0f', round(params(find(strcmp(order, PaperParams{end}))),0));
else
    fprintf(FID, '%8.2f', round(params(find(strcmp(order, PaperParams{end}))),2));
end
fprintf(FID, '\\\\\\hline ');
fprintf(FID,'\n');
fprintf(FID, '\\end{tabular}\n');
fclose(FID);

FID = fopen(fullfile(pwd,opts.results_path,opts.testGroup,'PresetParameterValuesVert.tex'),'w');
fprintf(FID, '\\begin{tabular}');
fprintf(FID, '{|');
fprintf(FID, 'r r r');
fprintf(FID, '|}');
fprintf(FID, '\\hline\n');
fprintf(FID, 'Parameter & Comment & Value');
fprintf(FID, '\\\\\\hline\n');
for i = opts.nparams:length(PaperParams)-opts.nparams
    fprintf(FID,sprintf('%s & %s &',ParamNames{i},ParamComment{i}));
    if params(find(strcmp(order, PaperParams{i}))) < 0.01
        fprintf(FID, '%8.4f\\\\\n', round(params(find(strcmp(order, PaperParams{i}))),4));
    elseif params(find(strcmp(order, PaperParams{i}))) < 1
        fprintf(FID, '%8.2f\\\\\n', round(params(find(strcmp(order, PaperParams{i}))),2));
    elseif params(find(strcmp(order, PaperParams{i}))) > 1 && rem(params(find(strcmp(order, PaperParams{i}))),1)==0
        fprintf(FID, '%8.0f\\\\\n', round(params(find(strcmp(order, PaperParams{i}))),0));
    else
        fprintf(FID, '%8.2f\\\\\n', round(params(find(strcmp(order, PaperParams{i}))),2));
    end
    if i==length(PaperParams)
        fprintf(FID, '\\hline ');
    end
    fprintf(FID,'\n');
end

fprintf(FID, '\\end{tabular}\n');
fclose(FID);


FID = fopen(fullfile(pwd,opts.results_path,opts.testGroup,'EstimParameterValues.tex'),'w');
fprintf(FID, '\\begin{tabular}');
fprintf(FID, '{|');
for j = 1:(opts.nparams+1)
    fprintf(FID, sprintf('%s','r'));
end
fprintf(FID, '|}');
fprintf(FID, '\\hline\n');
fprintf(FID, '& ');
for j = 1:(opts.nparams-1)
    fprintf(FID, sprintf('%s &',ParamNames{j}));
end
fprintf(FID, sprintf('%s',ParamNames{opts.nparams}));
fprintf(FID, '\\\\\\hline\n');
fprintf(FID, '& ');
for j = 1:(opts.nparams-1)
    fprintf(FID, sprintf('%s &',ParamComment{j}));
end
fprintf(FID, sprintf('%s',ParamComment{opts.nparams}));
fprintf(FID, '\n');
fprintf(FID, '& ');
for j = 1:(opts.nparams-1)
    if params(find(strcmp(order, PaperParams{j}))) < 0.01
        fprintf(FID, '%8.4f & ', round(params(find(strcmp(order, PaperParams{j}))),4));
    elseif params(find(strcmp(order, PaperParams{j}))) < 1
        fprintf(FID, '%8.2f & ', round(params(find(strcmp(order, PaperParams{j}))),2));
    elseif params(find(strcmp(order, PaperParams{j}))) > 1 && rem(params(find(strcmp(order, PaperParams{j}))),1)==0
        fprintf(FID, '%8.0f & ', round(params(find(strcmp(order, PaperParams{j}))),0));
    else
        fprintf(FID, '%8.2f & ', round(params(find(strcmp(order, PaperParams{j}))),2));
    end
end
if params(find(strcmp(order, PaperParams{opts.nparams}))) < 0.01
    fprintf(FID, '%8.4f', round(params(find(strcmp(order, PaperParams{opts.nparams}))),4));
elseif params(find(strcmp(order, PaperParams{opts.nparams}))) < 1
    fprintf(FID, '%8.2f', round(params(find(strcmp(order, PaperParams{opts.nparams}))),2));
elseif params(find(strcmp(order, PaperParams{opts.nparams}))) > 1 && rem(params(find(strcmp(order, PaperParams{opts.nparams}))),1)==0
    fprintf(FID, '%8.0f', round(params(find(strcmp(order, PaperParams{opts.nparams}))),0));
else
    fprintf(FID, '%8.2f', round(params(find(strcmp(order, PaperParams{opts.nparams}))),2));
end
fprintf(FID, '\\\\\\hline ');
fprintf(FID,'\n');
fprintf(FID, '\\end{tabular}\n');
fclose(FID);

FID = fopen(fullfile(pwd,opts.results_path,opts.testGroup,'EstimParameterValuesVert.tex'),'w');
fprintf(FID, '\\begin{tabular}');
fprintf(FID, '{|');
fprintf(FID, 'r r r');
fprintf(FID, '|}');
fprintf(FID, '\\hline\n');
fprintf(FID, 'Parameter & Comment & Value');
fprintf(FID, '\\\\\\hline\n');
for i = 1:opts.nparams
    fprintf(FID,sprintf('%s & %s &',ParamNames{i},ParamComment{i}));
    if params(find(strcmp(order, PaperParams{i}))) < 0.01
        fprintf(FID, '%8.4f\\\\\n', round(params(find(strcmp(order, PaperParams{i}))),4));
    elseif params(find(strcmp(order, PaperParams{i}))) < 1
        fprintf(FID, '%8.2f\\\\\n', round(params(find(strcmp(order, PaperParams{i}))),2));
    elseif params(find(strcmp(order, PaperParams{i}))) > 1 && rem(params(find(strcmp(order, PaperParams{i}))),1)==0
        fprintf(FID, '%8.0f\\\\\n', round(params(find(strcmp(order, PaperParams{i}))),0));
    else
        fprintf(FID, '%8.2f\\\\\n', round(params(find(strcmp(order, PaperParams{i}))),2));
    end
    if i==length(PaperParams)
        fprintf(FID, '\\hline ');
    end
    fprintf(FID,'\n');
end

fprintf(FID, '\\end{tabular}\n');
fclose(FID);


end
