function xmin = Main_Wrapper(params,opts,SMMopts,moments,distMoments,resultsSeries)
%%Main_Wrapper m-file for Labor Market Participation and the Minimum Wage
%Author: Adrian Masters and Ben Griffy
%Date: July 2020
%Description: this directs the options selected in "Main" to the correct files. It also creates the required subdirectories and separates parameters into estimated params (SMM_params) and non SMM params

params_array = NaN(length(fieldnames(params)),1);
order = [];

SMM_params = cellstr({SMMopts.SMM_params});

opts.nparams = length(SMM_params);

% Description: create directories for simulations and model solutions

if ~isequal(exist(fullfile(pwd,opts.graphics_path),'dir'),7)
    mkdir(fullfile(pwd,opts.graphics_path));
end
if ~isequal(exist(fullfile(pwd,opts.output_path),'dir'),7)
    mkdir(fullfile(pwd,opts.output_path));
end
if ~isequal(exist(fullfile(pwd,opts.SMM_path),'dir'),7)
    mkdir(fullfile(pwd,opts.SMM_path));
end
if opts.SMM == 'n'
    if ~isequal(exist(fullfile(pwd,opts.results_path),'dir'),7)
        mkdir(fullfile(pwd,opts.results_path));
    end
end


% This separates parameters into those that are calibrated and those that aren't
for j = 1:length(SMM_params)
    params_array(j) = params.(SMM_params{1,j});
    order{j,1} = SMM_params{1,j};
    params = rmfield(params,SMM_params{1,j});
end

keys = fieldnames(params);

% This reorders parameters so SMM params are at the end
for i = 1:length(keys)
    params_array(length(SMM_params)+i) = params.(keys{i,1});
    order(length(SMM_params)+ i) = keys(i);
end

    xmin = [];

    % set(QuestFig,'Visible','off');
    % If we are re-calibrating the model, SMM == 'y' and it will target the set of moments we define
    if opts.SMM == 'y'
        set(0,'defaultFigureVisible','off');
        if opts.solver == 'FS'
            options = optimset('Display','off');
            obj_fun = @(est_params)SMM_Wrapper([est_params; params_array(length(SMM_params)+1:end)],order,moments,distMoments,opts);
            [xmin,fval] = fminsearchbnd(obj_fun,params_array(1:length(SMM_params)),SMMopts(1).LB,SMMopts(1).UB,options);
        elseif opts.solver == 'PS'
            options = optimoptions('patternsearch','Display','iter','PlotFcn',{@psplotbestf,@psplotmeshsize},'PollOrderAlgorithm','Random','InitialMeshSize',0.00125);
            obj_fun = @(est_params)SMM_Wrapper([est_params; params_array(length(SMM_params)+1:end)],order,moments,distMoments,opts);
            [xmin,fval] = patternsearch(obj_fun,params_array(1:length(SMM_params)),SMMopts(1).A,SMMopts(1).B,SMMopts(1).Aeq,SMMopts(1).Beq,SMMopts(1).LB,SMMopts(1).UB,[],options);
        elseif strcat(opts.solver) == 'DR'
            options = struct('maxevals',10000000,'maxits',10000000,'showits',0,'tol',1e-6,'impcons',1);
            obj_fun = @(est_params)SMM_Wrapper([est_params; params_array(length(SMM_params)+1:end)],order,moments,distMoments,opts);
            myprob  = struct('f',obj_fun);
            bounds = reshape(cat(2,SMMopts(1).LB,SMMopts(1).UB),length(SMM_params),2);
            [fval,xmin,hist] = Direct(myprob,bounds,options);
        elseif strcat(opts.solver) == 'SA'
            hybridopts = optimoptions('patternsearch','Display','iter','PlotFcn',@psplotbestf,'Cache','on','UseCompletePoll',true,'UseCompleteSearch',true,'InitialMeshSize',0.00125);
            options = optimoptions(@simulannealbnd,'HybridFcn',{@patternsearch,hybridopts},'PlotFcn',{@saplotbestf, @saplotf},'ObjectiveLimit',0.0);
            obj_fun = @(est_params)SMM_Wrapper([est_params; params_array(length(SMM_params)+1:end)],order,moments,distMoments,opts);
            [xmin,fval] = simulannealbnd(obj_fun,params_array(1:length(SMM_params)),SMMopts(1).LB,SMMopts(1).UB,options);
        end
    elseif opts.SMM == 'n'
        xmin = [];
        MainFindings(params_array, order, moments, resultsSeries, opts); % this will run all of the other final results that we want
    end
end