function welfare = ModelMaxWelfMWUI(x,initWbar,initTheta,params,order,opts,solveOpts)
%%Model m-file for Labor Market Participation and the Minimum Wage
%Author: Adrian Masters and Ben Griffy
%Date: July 2020

% inputs
% x(1): market tightness (theta)
% wbarHat: cut-off productivity in planner's problem, minimum wage in decentralized problem.


[pphi,eeta,bbeta,a,z,r,llambda,m,mmu,ssigma,lb,ub,pphiDelt,zDelt,wbarDelt,wbinDelt,N,T,wbar,mFun,dmFun,wageFun,pFun,udotFun] = Parameters(params, order, opts);

wbarHat = x(1);
deltBbar = x(2);

if -z>deltBbar
    welfare=1
    % eqm=NaN
    % err = 1
    return
end

zHat = z + deltBbar;

% if wbarHat<zHat/(1-pphi)
%     welfare=1;
%     % eqm=NaN
%     % err = 1
%     return
% end


if strcmpi(solveOpts.prob,'planner') || strcmpi(solveOpts.prob,'plannerfixed')

    initPbarHat = max(initWbar,z);
    pbarHat = max(wbarHat,zHat);
    thetaHat = x(1);

    % Matching rate and matching rate derivative
    initMatRate = mFun(initTheta);
    initDmatRate = dmFun(initTheta);


    % outcome calculations
    initUratem = llambda/(initMatRate+llambda);    % unemployment rate u/(u+e)


    matRate = mFun(thetaHat);
    dmatRate = dmFun(thetaHat);

    unempRateMat = (((((llambda+matRate).*initUratem-llambda)).*exp(-(llambda+matRate)*linspace(0,T.TransMax,T.Trans+1))+llambda)./(llambda+matRate)).';
    unempRateMat = (1 - logncdf(pbarHat,mmu,ssigma)).*unempRateMat;

    % NILFRateMat(1) = logncdf(initPbarHat,mmu,ssigma);
    % NILFRateMat(2:end) = logncdf(pbarHat,mmu,ssigma);
    NILFRateMat = repmat(logncdf(pbarHat,mmu,ssigma),T.Trans+1,1);


    empRateMat=(1-unempRateMat-NILFRateMat); % emplyment as share of totsal population


    % outcome calculations
    uratem=llambda/(matRate+llambda);    % unemployment rate u/(u+e)

    NILF=logncdf(pbarHat,mmu,ssigma);   % share of poulation excluded from market

    empRate=(1-NILF)*(1-uratem); % emplyment as share of totsal population
    unempRate=1-empRate-NILF;



    welfNILF = repmat((zHat+(z-zHat)).*logncdf(pbarHat,mmu,ssigma),T.Trans+1,1);

    welfUnemp = unempRateMat.*(zHat+(z-zHat));


    welfEmp = (empRateMat./(1 - logncdf(pbarHat,mmu,ssigma))).*integral(@(x)(x.*lognpdf(x,mmu,ssigma)),pbarHat,inf);

    welfVac = -thetaHat.*unempRateMat.*a;

    welfVec = exp(-r.*linspace(0,T.TransMax,T.Trans+1).').*(welfNILF + welfUnemp + welfEmp + welfVac);

    % averaged welfare
    welfare = -((2*sum(welfVec)-welfVec(1)-welfVec(end))*(T.TransMax./T.Trans)./2 + welfVec(end)./r);

elseif strcmpi(solveOpts.prob,'decentralparticipation') || strcmpi(solveOpts.prob,'decentralparticipationfixed')

    initPbarHat = max(initWbar,z);
    pbarHat = max(wbarHat,zHat);

    initSolveOpts = solveOpts.prob;
    solveOpts.prob = 'decentralparticipationfixed';

    options = optimoptions('fsolve','Display','none','Diagnostics','off','FunctionTolerance',1e-9,'MaxIterations',1000,'MaxFunctionEvaluations',2000,'OptimalityTolerance',1e-9);
    % options = optimset('Display','off','Diagnostics','off');
    obj_fun = @(theta)ModelMWUI([theta; pbarHat],params,order,opts,solveOpts);
    [xmin,~]=fsolve(obj_fun,0.05,options);  % may need to change starting values depanding on b and phi

    solveOpts.prob = initSolveOpts;

    thetaHat = xmin
    % thetaHat = x(1);

    % Matching rate and matching rate derivative
    initMatRate = mFun(initTheta);
    initDmatRate = dmFun(initTheta);


    % outcome calculations
    initUratem = llambda/(initMatRate+llambda);    % unemployment rate u/(u+e)


    matRate = mFun(thetaHat);
    dmatRate = dmFun(thetaHat);

    unempRateMat = (((((llambda+matRate).*initUratem-llambda)).*exp(-(llambda+matRate)*linspace(0,T.TransMax,T.Trans+1))+llambda)./(llambda+matRate)).';
    unempRateMat = (1 - logncdf(pbarHat,mmu,ssigma)).*unempRateMat;

    % NILFRateMat(1) = logncdf(initPbarHat,mmu,ssigma);
    % NILFRateMat(2:end) = logncdf(pbarHat,mmu,ssigma);
    NILFRateMat = repmat(logncdf(pbarHat,mmu,ssigma),T.Trans+1,1);


    empRateMat=(1-unempRateMat-NILFRateMat); % emplyment as share of totsal population


    % outcome calculations
    uratem=llambda/(matRate+llambda);    % unemployment rate u/(u+e)

    NILF=logncdf(pbarHat,mmu,ssigma);   % share of poulation excluded from market

    empRate=(1-NILF)*(1-uratem); % emplyment as share of totsal population
    unempRate=1-empRate-NILF;



    welfNILF = repmat((zHat+(z-zHat)).*logncdf(pbarHat,mmu,ssigma),T.Trans+1,1);

    welfUnemp = unempRateMat.*(zHat+(z-zHat));


    welfEmp = (empRateMat./(1 - logncdf(pbarHat,mmu,ssigma))).*integral(@(x)(x.*lognpdf(x,mmu,ssigma)),pbarHat,inf);

    welfVac = -thetaHat.*unempRateMat.*a;

    welfVec = exp(-r.*linspace(0,T.TransMax,T.Trans+1).').*(welfNILF + welfUnemp + welfEmp + welfVac);

    % averaged welfare
    welfare = -((2*sum(welfVec)-welfVec(1)-welfVec(end))*(T.TransMax./T.Trans)./2 + welfVec(end)./r);

else % decentralized problem

    % Matching rate and matching rate derivative
    initMatRate = mFun(initTheta);
    initDmatRate = dmFun(initTheta);

    initSolveOpts = solveOpts.prob;
    solveOpts.prob = 'decentralfixed';


    options = optimoptions('fsolve','Display','none','Diagnostics','off','FunctionTolerance',1e-9,'MaxIterations',1000,'MaxFunctionEvaluations',2000,'OptimalityTolerance',1e-9);
    % options = optimset('Display','off','Diagnostics','off');
    zInit = params(find(strcmp(order, 'z')));
    params(find(strcmp(order, 'z'))) = zHat;
    obj_fun = @(theta)ModelMWUI([theta; max(wbarHat,zHat)],params,order,opts,solveOpts);
    [xmin,~]=fsolve(obj_fun,0.05,options);  % may need to change starting values depanding on b and phi
    params(strcmp(order,'z')) = zInit;

    solveOpts.prob = initSolveOpts;

    thetaHat = xmin

    % outcome calculations
    initUratem = llambda/(initMatRate+llambda);    % unemployment rate u/(u+e)


    matRate = mFun(thetaHat);
    dmatRate = dmFun(thetaHat);

    unempRateMat = (((((llambda+matRate).*initUratem-llambda)).*exp(-(llambda+matRate)*linspace(0,T.TransMax,T.Trans+1))+llambda)./(llambda+matRate)).';
    unempRateMat = (1 - logncdf(max(wbarHat,zHat),mmu,ssigma)).*unempRateMat;


    NILFRateMat = zeros(T.Trans+1,1);
    % NILFRateMat(1) = logncdf(initWbarHat,mmu,ssigma);
    % NILFRateMat(2:end) = logncdf(wbarHat,mmu,ssigma);
    NILFRateMat = repmat(logncdf(max(wbarHat,zHat),mmu,ssigma),T.Trans+1,1);


    empRateMat = zeros(T.Trans+1,1);
    empRateMat=(1-unempRateMat-NILFRateMat); % emplyment as share of totsal population
    % empRateMat(1) = 1 - (1 - logncdf(initWbarHat,mmu,ssigma))*(1 - initUratem) -  logncdf(initWbarHat,mmu,ssigma);


    uratem=llambda/(matRate+llambda);    % unemployment rate u/(u+e)

    NILF=logncdf(max(wbarHat,zHat),mmu,ssigma);   % share of poulation excluded from market

    empRate=(1-NILF)*(1-uratem); % emplyment as share of totsal population
    unempRate=1-empRate-NILF;

    welfNILF = repmat((zHat+(z-zHat)).*logncdf(max(wbarHat,zHat),mmu,ssigma),T.Trans+1,1);

    welfUnemp = unempRateMat.*(zHat+(z-zHat));

    welfEmp = (empRateMat./(1 - logncdf(max(wbarHat,zHat),mmu,ssigma))).*integral(@(x)(x.*lognpdf(x,mmu,ssigma)),max(wbarHat,zHat),inf);

    welfVac = -thetaHat.*unempRateMat.*a;

    welfVec = exp(-r.*linspace(0,T.TransMax,T.Trans+1).').*(welfNILF + welfUnemp + welfEmp + welfVac);

    % averaged welfare
    welfare = -((2*sum(welfVec)-welfVec(1)-welfVec(end))*(T.TransMax./T.Trans)./2 + welfVec(end)./r);


end


% eqm;

end
