function err = ModelMaxWelfMWUI_Wrapper(params,order,opts,initTheta,initWbar,solveOpts)
%%Model_Wrapper m-file for Labor Market Participation and the Minimum Wage
%Author: Adrian Masters and Ben Griffy
%Date: July 2020

[pphi,eeta,bbeta,a,z,r,llambda,m,mmu,ssigma,lb,ub,pphiDelt,zDelt,wbarDelt,wbinDelt,N,T,wbar,mFun,dmFun,wageFun,pFun,udotFun] = Parameters(params, order, opts);

if ~isequal(exist(fullfile(pwd,opts.output_path),'dir'),7)
    mkdir(fullfile(pwd,opts.output_path));
end

err = 0

if strcmpi(solveOpts.prob, 'planner') || strcmpi(solveOpts.prob, 'plannerfixed')

    if strcmpi(solveOpts.prob, 'planner')

        options = optimset('Display','off','Diagnostics','off');
        obj_fun = @(x)ModelMaxWelfPlanner(x, initWbar, initTheta, params,order,opts,solveOpts);
        xmin=fminsearch(obj_fun,[0.07,8],options);  % may need to change starting values depanding on b and phi

        thetaHat = xmin(1)
        pbarHat=xmin(2)

        matfile = fullfile(pwd,opts.output_path,'solutionPlanner.mat');

        save(matfile, 'thetaHat', 'pbarHat');
    elseif strcmpi(solveOpts.prob, 'plannerfixed')

        obj_fun = @(theta)Model([theta,wbar],params,order,opts,solveOpts);
        xmin=fsolve(obj_fun,0.08);  % may need to change starting values depanding on b and phi

        thetaHat=xmin
        pbarHat=max(wbar,z)

        matfile = fullfile(pwd,opts.output_path,'solutionPlanner.mat');

        save(matfile, 'thetaHat', 'pbarHat');
    end

else

    if strcmpi(solveOpts.prob,'calib')

        % options = optimoptions('fminsearch','Display','none','Diagnostics','off','FunctionTolerance',1e-9,'MaxIterations',1000,'MaxFunctionEvaluations',2000,'OptimalityTolerance',1e-9);
        options = optimset('Display','off','Diagnostics','off');
        zInit = params(find(strcmp(order, 'z')));
        params(find(strcmp(order, 'z'))) = zHat;
        obj_fun = @(theta)Model([theta; wbar],params,order,opts,solveOpts);
        [xmin,~]=fsolve(obj_fun,0.07,options);  % may need to change starting values depanding on b and phi
        params(strcmpi(order,'z')) = zInit;

        thetaHat = xmin
        wbarHat = wbar
        zHat = z

        matfile = fullfile(pwd,opts.output_path,'solutionCalib.mat');

        save(matfile, 'thetaHat', 'wbarHat', 'zHat');
    elseif strcmpi(solveOpts.prob,'decentralbothfixed')

        % options = optimoptions('fminsearch','Display','none','Diagnostics','off','FunctionTolerance',1e-9,'MaxIterations',1000,'MaxFunctionEvaluations',2000,'OptimalityTolerance',1e-9);
        options = optimset('Display','off','Diagnostics','off');
        zInit = params(find(strcmp(order, 'z')));
        params(find(strcmp(order, 'z'))) = zHat;
        obj_fun = @(theta)Model([theta; wbar],params,order,opts,solveOpts);
        [xmin,~]=fsolve(obj_fun,0.07,options);  % may need to change starting values depanding on b and phi
        params(strcmpi(order,'z')) = zInit;

        % matRate*(1-bbeta)*((1-pphi)*Ebar-z)-a*x(1)*rlbm

        thetaHat = xmin
        wbarHat = wbar
        zHat = z

        matfile = fullfile(pwd,opts.output_path,'solutionDecentralBoth.mat');

        save(matfile, 'thetaHat', 'wbarHat', 'zHat');

    elseif strcmpi(solveOpts.prob,'decentralbothparticipation')

        % options = optimoptions('fminsearch','Display','none','Diagnostics','off');
        options = optimset('Display','off','Diagnostics','off');
        obj_fun = @(x)ModelMaxWelfMWUI(x, initWbar, initTheta, params,order,opts,solveOpts);
        xmin=fminsearch(obj_fun,[wbar,0],options);  % may need to change starting b and phi

        wbarHat = xmin(1)
        zHat = z + xmin(2)

        solveOpts.prob = 'decentralbothparticipationfixed';

        options = optimoptions('fsolve','Display','none','Diagnostics','off','FunctionTolerance',1e-9,'MaxIterations',1000,'MaxFunctionEvaluations',2000,'OptimalityTolerance',1e-9);
        % options = optimset('Display','off','Diagnostics','off');
        zInit = params(find(strcmp(order, 'z')));
        params(find(strcmp(order, 'z'))) = zHat;
        obj_fun = @(theta)Model([theta; wbarHat],params,order,opts,solveOpts);
        [xmin,~]=fsolve(obj_fun,0.07,options);  % may need to change starting values depanding on b and phi
        params(strcmpi(order,'z')) = zInit;

        thetaHat = xmin

        solveOpts.prob = 'decentralbothparticipation';

        matfile = fullfile(pwd,opts.output_path,'solutionDecentralBothParticipation.mat');

        save(matfile, 'thetaHat', 'wbarHat', 'zHat');

    elseif strcmp(solveOpts.prob,'decentralbothparticipationfixed')

        % options = optimoptions('fminsearch','Display','none','Diagnostics','off','FunctionTolerance',1e-9,'MaxIterations',1000,'MaxFunctionEvaluations',2000,'OptimalityTolerance',1e-9);
        options = optimset('Display','off','Diagnostics','off');
        obj_fun = @(theta)Model([theta; wbar],params,order,opts,solveOpts);
        [xmin,~]=fsolve(obj_fun,0.08,options);  % may need to change starting values depanding on b and phi

        thetaHat = xmin
        wbarHat = wbar
        zHat = z

        matfile = fullfile(pwd,opts.output_path,'solutionDecentralBothParticipation.mat');

        save(matfile, 'thetaHat', 'wbarHat', 'zHat');


    else
        % options = optimoptions('fminsearch','Display','none','Diagnostics','off','FunctionTolerance',1e-9,'MaxIterations',1000,'MaxFunctionEvaluations',2000,'OptimalityTolerance',1e-9);
        options = optimset('Display','off','Diagnostics','off');
        obj_fun = @(x)ModelMaxWelfMWUI(x,initWbar,initTheta,params,order,opts,solveOpts);
        % xmin=fminsearch(obj_fun,[0.08;max(6,(z/(1-pphi))+1)]);  % may need to change starting values depanding on b and phi
        xmin=fminsearch(obj_fun,[wbar,2],options);  % may need to change starting values depanding on b and phi

        wbarHat = xmin(1)
        zHat = z + xmin(2)

        solveOpts.prob = 'decentralbothfixed';

        options = optimoptions('fsolve','Display','none','Diagnostics','off','FunctionTolerance',1e-9,'MaxIterations',1000,'MaxFunctionEvaluations',2000,'OptimalityTolerance',1e-9);
        % options = optimset('Display','off','Diagnostics','off');
        zInit = params(find(strcmp(order, 'z')));
        params(find(strcmp(order, 'z'))) = zHat;
        obj_fun = @(theta)ModelMWUI([theta; max(wbarHat,zHat)],params,order,opts,solveOpts);
        [xmin,~]=fsolve(obj_fun,0.05,options);  % may need to change starting values depanding on b and phi
        params(strcmp(order,'z')) = zInit;

        thetaHat = xmin

        solveOpts.prob = 'decentralboth';


        matfile = fullfile(pwd,opts.output_path,'solutionDecentralBoth.mat');

        save(matfile, 'thetaHat', 'wbarHat', 'zHat');
    end

end


end
