function welfare = ModelMaxWelfPlanner(x,initWbar,initTheta,params,order,opts,solveOpts)
%%Model m-file for Labor Market Participation and the Minimum Wage
%Author: Adrian Masters and Ben Griffy
%Date: July 2020

% inputs
% x(1): market tightness (theta)
% wbarHat: cut-off productivity in planner's problem, minimum wage in decentralized problem.


[pphi,eeta,bbeta,a,z,r,llambda,m,mmu,ssigma,lb,ub,pphiDelt,zDelt,wbarDelt,wbinDelt,N,T,wbar,mFun,dmFun,wageFun,pFun,udotFun] = Parameters(params, order, opts);

zHat = z;


if x(1)<=0 || x(2)<z/(1-pphi)
    welfare = 1;
    % eqm = NaN
    % err = 1
    return
end




    initPbarHat = initWbar;
    pbarHat = x(2);
    thetaHat = x(1);

    % Matching rate and matching rate derivative
    initMatRate = mFun(initTheta);
    initDmatRate = dmFun(initTheta);


    % outcome calculations
    initUratem = llambda/(initMatRate+llambda);    % unemployment rate u/(u+e)


    matRate = mFun(thetaHat);
    dmatRate = dmFun(thetaHat);

    unempRateMat = (((((llambda+matRate).*initUratem-llambda)).*exp(-(llambda+matRate)*linspace(0,T.TransMax,T.Trans+1))+llambda)./(llambda+matRate)).';
    unempRateMat = (1 - logncdf(pbarHat,mmu,ssigma)).*unempRateMat;

    NILFRateMat = zeros(T.Trans+1,1);
    % NILFRateMat(1) = logncdf(initPbarHat,mmu,ssigma);
    % NILFRateMat(2:end) = logncdf(pbarHat,mmu,ssigma);
    NILFRateMat = repmat(logncdf(pbarHat,mmu,ssigma),T.Trans+1,1);


    empRateMat = zeros(T.Trans+1,1);
    empRateMat=(1-unempRateMat-NILFRateMat); % emplyment as share of totsal population


    % outcome calculations
    uratem=llambda/(matRate+llambda);    % unemployment rate u/(u+e)

    NILF=logncdf(pbarHat,mmu,ssigma);   % share of poulation excluded from market

    empRate=(1-NILF)*(1-uratem); % emplyment as share of totsal population
    unempRate=1-empRate-NILF;



    welfNILF = repmat((zHat+(z-zHat)).*logncdf(pbarHat,mmu,ssigma),T.Trans+1,1);

    welfUnemp = unempRateMat.*(zHat+(z-zHat));


    welfEmp = (empRateMat./(1 - logncdf(pbarHat,mmu,ssigma))).*integral(@(x)(x.*lognpdf(x,mmu,ssigma)),pbarHat,inf);

    welfVac = -thetaHat.*unempRateMat.*a;

    welfVec = exp(-r.*linspace(0,T.TransMax,T.Trans+1).').*(welfNILF + welfUnemp + welfEmp + welfVac);

    % averaged welfare
    welfare = -((2*sum(welfVec)-welfVec(1)-welfVec(end))*(T.TransMax./T.Trans)./2 + welfVec(end)./r);



% eqm;

end
