function welfare = ModelMaxWelfVac(wbarHat,initWbar,initTheta,params,order,opts,solveOpts)
%%Model m-file for Labor Market Participation and the Minimum Wage
%Author: Adrian Masters and Ben Griffy
%Date: July 2020

% inputs
% x(1): market tightness (theta)
% wbarHat: cut-off productivity in planner's problem, minimum wage in decentralized problem.


[pphi,eeta,bbeta,a,z,r,llambda,m,mmu,ssigma,lb,ub,pphiDelt,zDelt,wbarDelt,wbinDelt,N,T,wbar,mFun,dmFun,wageFun,pFun,udotFun] = Parameters(params, order, opts);

zHat = z;


if wbarHat<z/(1-pphi)
    welfare=1;
    % eqm=NaN
    % err = 1
    return
end


if strcmpi(solveOpts.prob,'planner') || strcmpi(solveOpts.prob,'plannerfixed')

    initPbarHat = initWbar;
    pbarHat = wbarHat;
    thetaHat = x(1);

    % Matching rate and matching rate derivative
    initMatRate = mFun(initTheta);
    initDmatRate = dmFun(initTheta);


    % outcome calculations
    initUratem = llambda/(initMatRate+llambda);    % unemployment rate u/(u+e)


    matRate = mFun(thetaHat);
    dmatRate = dmFun(thetaHat);

    unempRateMat = (((((llambda+matRate).*initUratem-llambda)).*exp(-(llambda+matRate)*linspace(0,T.TransMax,T.Trans+1))+llambda)./(llambda+matRate)).';
    unempRateMat = (1 - logncdf(pbarHat,mmu,ssigma)).*unempRateMat;

    % NILFRateMat(1) = logncdf(initPbarHat,mmu,ssigma);
    % NILFRateMat(2:end) = logncdf(pbarHat,mmu,ssigma);
    NILFRateMat = repmat(logncdf(pbarHat,mmu,ssigma),T.Trans+1,1);


    empRateMat=(1-unempRateMat-NILFRateMat); % emplyment as share of totsal population


    % outcome calculations
    uratem=llambda/(matRate+llambda);    % unemployment rate u/(u+e)

    NILF=logncdf(pbarHat,mmu,ssigma);   % share of poulation excluded from market

    empRate=(1-NILF)*(1-uratem); % emplyment as share of totsal population
    unempRate=1-empRate-NILF;



    welfNILF = repmat((zHat+(z-zHat)).*logncdf(pbarHat,mmu,ssigma),T.Trans+1,1);

    welfUnemp = unempRateMat.*(zHat+(z-zHat));


    welfEmp = (empRateMat./(1 - logncdf(pbarHat,mmu,ssigma))).*integral(@(x)(x.*lognpdf(x,mmu,ssigma)),pbarHat,inf);

    welfVac = -thetaHat.*unempRateMat.*a;

    welfVec = exp(-r.*linspace(0,T.TransMax,T.Trans+1).').*(welfNILF + welfUnemp + welfEmp + welfVac);

    % averaged welfare
    welfare = -((2*sum(welfVec)-welfVec(1)-welfVec(end))*(T.TransMax./T.Trans)./2 + welfVec(end)./r);

elseif strcmpi(solveOpts.prob,'decentralparticipation') || strcmpi(solveOpts.prob,'decentralparticipationfixed')

    initPbarHat = initWbar;
    pbarHat = wbarHat;

    initSolveOpts = solveOpts.prob;
    solveOpts.prob = 'decentralparticipationfixed';

    options = optimoptions('fsolve','Display','none','Diagnostics','off','FunctionTolerance',1e-9,'MaxIterations',1000,'MaxFunctionEvaluations',2000,'OptimalityTolerance',1e-9);
    % options = optimset('Display','off','Diagnostics','off');
    obj_fun = @(theta)Model([theta; pbarHat],params,order,opts,solveOpts);
    [xmin,~]=fsolve(obj_fun,0.05,options);  % may need to change starting values depanding on b and phi

    solveOpts.prob = initSolveOpts;

    thetaHat = xmin
    % thetaHat = x(1);

    % Matching rate and matching rate derivative
    initMatRate = mFun(initTheta);
    initDmatRate = dmFun(initTheta);


    % outcome calculations
    initUratem = llambda/(initMatRate+llambda);    % unemployment rate u/(u+e)


    matRate = mFun(thetaHat);
    dmatRate = dmFun(thetaHat);

    unempRateMat = (((((llambda+matRate).*initUratem-llambda)).*exp(-(llambda+matRate)*linspace(0,T.TransMax,T.Trans+1))+llambda)./(llambda+matRate)).';
    unempRateMat = (1 - logncdf(pbarHat,mmu,ssigma)).*unempRateMat;

    % NILFRateMat(1) = logncdf(initPbarHat,mmu,ssigma);
    % NILFRateMat(2:end) = logncdf(pbarHat,mmu,ssigma);
    NILFRateMat = repmat(logncdf(pbarHat,mmu,ssigma),T.Trans+1,1);


    empRateMat=(1-unempRateMat-NILFRateMat); % emplyment as share of totsal population


    % outcome calculations
    uratem=llambda/(matRate+llambda);    % unemployment rate u/(u+e)

    NILF=logncdf(pbarHat,mmu,ssigma);   % share of poulation excluded from market

    empRate=(1-NILF)*(1-uratem); % emplyment as share of totsal population
    unempRate=1-empRate-NILF;



    welfNILF = repmat((zHat+(z-zHat)).*logncdf(pbarHat,mmu,ssigma),T.Trans+1,1);

    welfUnemp = unempRateMat.*(zHat+(z-zHat));


    welfEmp = (empRateMat./(1 - logncdf(pbarHat,mmu,ssigma))).*integral(@(x)(x.*lognpdf(x,mmu,ssigma)),pbarHat,inf);

    welfVac = -thetaHat.*unempRateMat.*a;

    welfVec = exp(-r.*linspace(0,T.TransMax,T.Trans+1).').*(welfNILF + welfUnemp + welfEmp + welfVac);

    % averaged welfare
    welfare = -((2*sum(welfVec)-welfVec(1)-welfVec(end))*(T.TransMax./T.Trans)./2 + welfVec(end)./r);

else % decentralized problem

    % Matching rate and matching rate derivative
    initMatRate = mFun(initTheta);
    initDmatRate = dmFun(initTheta);

    initSolveOpts = solveOpts.prob;
    solveOpts.prob = 'decentralfixed';


    options = optimoptions('fsolve','Display','none','Diagnostics','off','FunctionTolerance',1e-9,'MaxIterations',1000,'MaxFunctionEvaluations',2000,'OptimalityTolerance',1e-9);
    % options = optimset('Display','off','Diagnostics','off');
    obj_fun = @(theta)Model([theta; wbarHat],params,order,opts,solveOpts);
    [xmin,~]=fsolve(obj_fun,0.05,options);  % may need to change starting values depanding on b and phi

    solveOpts.prob = initSolveOpts;

    thetaHat = xmin

    % outcome calculations
    initUratem = llambda/(initMatRate+llambda);    % unemployment rate u/(u+e)


    % unempRateMat2 = zeros(T.Trans,1);
    % unempRateMat2(1) = 1 - (1 - logncdf(initWbarHat,mmu,ssigma))*(1 - initUratem) -  logncdf(initWbarHat,mmu,ssigma);
    % unempRateMat2(2) = (1 - (logncdf(wbarHat,mmu,ssigma)- logncdf(initWbarHat,mmu,ssigma))).*unempRateMat2(1) + llambda.*(1 - logncdf(wbarHat,mmu,ssigma) - (1 - (logncdf(wbarHat,mmu,ssigma)- logncdf(initWbarHat,mmu,ssigma))).*unempRateMat2(1)) - mFun(x(1)).*(1 - (logncdf(wbarHat,mmu,ssigma)- logncdf(initWbarHat,mmu,ssigma))).*unempRateMat2(1);
    % unempRateMat2(2) = (1 - (logncdf(wbarHat,mmu,ssigma) - logncdf(initWbarHat,mmu,ssigma))).*unempRateMat2(1);


    % for i = 3:T.Trans
    %     unempRateMat2(i) = unempRateMat2(i-1) + udotFun(wbarHat,x(1),unempRateMat2(i-1));
    % end

    % unempRateMat = zeros(T.Trans,1);
    % % unempRateMat(1) = 1 - (1 - logncdf(initWbarHat,mmu,ssigma))*(1 - initUratem) -  logncdf(initWbarHat,mmu,ssigma);
    % % unempRateMat(2) = (1 - (logncdf(wbarHat,mmu,ssigma) - logncdf(initWbarHat,mmu,ssigma))).*unempRateMat(1);
    % unempRateMat(1) = (1 - (logncdf(wbarHat,mmu,ssigma) - logncdf(initWbarHat,mmu,ssigma))).*(1 - (1 - logncdf(initWbarHat,mmu,ssigma))*(1 - initUratem) -  logncdf(initWbarHat,mmu,ssigma));

    % matRate = mFun(x(1));
    % dmatRate = dmFun(x(1));

    % for t = 1:T.Trans
    %     unempRateMat(t) = llambda*(1 - logncdf(wbarHat,mmu,ssigma))./(llambda + matRate) + (unempRateMat(1) - llambda*(1 - logncdf(wbarHat,mmu,ssigma))./(llambda + matRate)).*exp(-(llambda + matRate).*t);
    % end

    matRate = mFun(thetaHat);
    dmatRate = dmFun(thetaHat);

    unempRateMat = (((((llambda+matRate).*initUratem-llambda)).*exp(-(llambda+matRate)*linspace(0,T.TransMax,T.Trans+1))+llambda)./(llambda+matRate)).';
    unempRateMat = (1 - logncdf(wbarHat,mmu,ssigma)).*unempRateMat;


    NILFRateMat = zeros(T.Trans+1,1);
    % NILFRateMat(1) = logncdf(initWbarHat,mmu,ssigma);
    % NILFRateMat(2:end) = logncdf(wbarHat,mmu,ssigma);
    NILFRateMat = repmat(logncdf(wbarHat,mmu,ssigma),T.Trans+1,1);


    empRateMat = zeros(T.Trans+1,1);
    empRateMat=(1-unempRateMat-NILFRateMat); % emplyment as share of totsal population
    % empRateMat(1) = 1 - (1 - logncdf(initWbarHat,mmu,ssigma))*(1 - initUratem) -  logncdf(initWbarHat,mmu,ssigma);


    uratem=llambda/(matRate+llambda);    % unemployment rate u/(u+e)

    NILF=logncdf(wbarHat,mmu,ssigma);   % share of poulation excluded from market

    empRate=(1-NILF)*(1-uratem); % emplyment as share of totsal population
    unempRate=1-empRate-NILF;

    welfNILF = repmat((zHat+(z-zHat)).*logncdf(wbarHat,mmu,ssigma),T.Trans+1,1);

    welfUnemp = unempRateMat.*(zHat+(z-zHat));

    welfEmp = (empRateMat./(1 - logncdf(wbarHat,mmu,ssigma))).*integral(@(x)(x.*lognpdf(x,mmu,ssigma)),wbarHat,inf);

    welfVac = -thetaHat.*unempRateMat.*a;

    welfVec = exp(-r.*linspace(0,T.TransMax,T.Trans+1).').*(welfNILF + welfUnemp + welfEmp + welfVac);

    % averaged welfare
    welfare = -((2*sum(welfVec)-welfVec(1)-welfVec(end))*(T.TransMax./T.Trans)./2 + welfVec(end)./r);


end


% eqm;

end
