function err = ModelMaxWelfVac_Wrapper(params,order,opts,initTheta,initWbar,solveOpts)
%%Model_Wrapper m-file for Labor Market Participation and the Minimum Wage
%Author: Adrian Masters and Ben Griffy
%Date: July 2020

[pphi,eeta,bbeta,a,z,r,llambda,m,mmu,ssigma,lb,ub,pphiDelt,zDelt,wbarDelt,wbinDelt,N,T,wbar,mFun,dmFun,wageFun,pFun,udotFun] = Parameters(params, order, opts);

if ~isequal(exist(fullfile(pwd,opts.output_path),'dir'),7)
    mkdir(fullfile(pwd,opts.output_path));
end

err = 0

if strcmpi(solveOpts.prob, 'planner') || strcmpi(solveOpts.prob, 'plannerfixed')

    if strcmpi(solveOpts.prob, 'planner')

        options = optimset('Display','off','Diagnostics','off');
        obj_fun = @(x)ModelMaxWelfPlanner(x, initWbar, initTheta, params,order,opts,solveOpts);
        xmin=fminsearch(obj_fun,[0.07,8],options);  % may need to change starting values depanding on b and phi

        thetaHat = xmin(1)
        pbarHat=xmin(2)

        matfile = fullfile(pwd,opts.output_path,'solutionPlanner.mat');

        save(matfile, 'thetaHat', 'pbarHat');
    elseif strcmpi(solveOpts.prob, 'plannerfixed')

        obj_fun = @(theta)Model([theta,wbar],params,order,opts,solveOpts);
        xmin=fsolve(obj_fun,0.08);  % may need to change starting values depanding on b and phi

        thetaHat=xmin
        pbarHat=wbar

        matfile = fullfile(pwd,opts.output_path,'solutionPlanner.mat');

        save(matfile, 'thetaHat', 'pbarHat');
    end

else

    options = optimset('Display','off','Diagnostics','off');
    obj_fun = @(x)ModelMaxWelfPlanner(x, initWbar, initTheta, params,order,opts,solveOpts);
    xmin=fminsearch(obj_fun,[0.07,8],options);  % may need to change starting values depanding on b and phi

    thetaHat = xmin(1)
    pbarHat=xmin(2)


    if strcmpi(solveOpts.prob, 'decentralvacmw')

        % ps=(rlbm*x(3)-(1-bbeta)*rl*z)/DENps;   %psquigle see p.(R.8)

        % options = optimoptions('fminsearch','Display','none','Diagnostics','off','FunctionTolerance',1e-9,'MaxIterations',1000,'MaxFunctionEvaluations',2000,'OptimalityTolerance',1e-9);
        options = optimset('Display','off','Diagnostics','off');
        obj_fun = @(vacSubs)ModelVac([vacSubs; thetaHat; pbarHat],params,order,opts,solveOpts);
        [xmin,~]=fsolve(obj_fun,0,options);  % may need to change starting values depanding on b and phi

        vacSubs = xmin

        matfile = fullfile(pwd,opts.output_path,'solutionDecentralVac.mat');

        save(matfile, 'vacSubs', 'thetaHat', 'pbarHat');
    else

        % zInit = params(find(strcmp(order, 'z')));
        % params(find(strcmp(order, 'z'))) = pbarHat;
        zDelt = pbarHat - z;

        % options = optimoptions('fminsearch','Display','none','Diagnostics','off','FunctionTolerance',1e-9,'MaxIterations',1000,'MaxFunctionEvaluations',2000,'OptimalityTolerance',1e-9);
        options = optimset('Display','off','Diagnostics','off');
        obj_fun = @(vacSubs)ModelVac([vacSubs; thetaHat; zDelt],params,order,opts,solveOpts);
        [xmin,~]=fsolve(obj_fun,0,options);  % may need to change starting values depanding on b and phi

        % params(find(strcmp(order, 'z'))) = zInit;

        vacSubs = xmin

        matfile = fullfile(pwd,opts.output_path,'solutionDecentralVac.mat');

        save(matfile, 'vacSubs', 'thetaHat', 'pbarHat');

    end

end


end
