function err = ModelMaxWelf_Wrapper(params,order,opts,initTheta,initWbar,solveOpts)
%%Model_Wrapper m-file for Labor Market Participation and the Minimum Wage
%Author: Adrian Masters and Ben Griffy
%Date: July 2020

[pphi,eeta,bbeta,a,z,r,llambda,m,mmu,ssigma,lb,ub,pphiDelt,zDelt,wbarDelt,wbinDelt,N,T,wbar,mFun,dmFun,wageFun,pFun,udotFun] = Parameters(params, order, opts);

if ~isequal(exist(fullfile(pwd,opts.output_path),'dir'),7)
    mkdir(fullfile(pwd,opts.output_path));
end

err = 0

if strcmpi(solveOpts.prob, 'planner') || strcmpi(solveOpts.prob, 'plannerfixed')

    if strcmpi(solveOpts.prob, 'planner')

        options = optimset('Display','off','Diagnostics','off');
        obj_fun = @(x)ModelMaxWelfPlanner(x, initWbar, initTheta, params,order,opts,solveOpts);
        xmin=fminsearch(obj_fun,[0.07,8],options);  % may need to change starting values depanding on b and phi

        thetaHat = xmin(1)
        pbarHat=xmin(2)

        matfile = fullfile(pwd,opts.output_path,'solutionPlanner.mat');

        save(matfile, 'thetaHat', 'pbarHat');
    elseif strcmpi(solveOpts.prob, 'plannerfixed')

        obj_fun = @(theta)Model([theta,wbar],params,order,opts,solveOpts);
        xmin=fsolve(obj_fun,0.08);  % may need to change starting values depanding on b and phi

        thetaHat=xmin
        pbarHat=wbar

        matfile = fullfile(pwd,opts.output_path,'solutionPlanner.mat');

        save(matfile, 'thetaHat', 'pbarHat');
    end

else

    if strcmpi(solveOpts.prob,'calib')

        % options = optimoptions('fminsearch','Display','none','Diagnostics','off','FunctionTolerance',1e-9,'MaxIterations',1000,'MaxFunctionEvaluations',2000,'OptimalityTolerance',1e-9);
        options = optimset('Display','off','Diagnostics','off');
        obj_fun = @(theta)Model([theta; wbar],params,order,opts,solveOpts);
        [xmin,~]=fsolve(obj_fun,0.07,options);  % may need to change starting values depanding on b and phi

        thetaHat = xmin
        wbarHat = wbar

        matfile = fullfile(pwd,opts.output_path,'solutionCalib.mat');

        save(matfile, 'thetaHat', 'wbarHat');
    elseif strcmpi(solveOpts.prob,'decentralfixed')

        % options = optimoptions('fminsearch','Display','none','Diagnostics','off','FunctionTolerance',1e-9,'MaxIterations',1000,'MaxFunctionEvaluations',2000,'OptimalityTolerance',1e-9);
        options = optimset('Display','off','Diagnostics','off');
        obj_fun = @(theta)Model([theta; wbar],params,order,opts,solveOpts);
        [xmin,~]=fsolve(obj_fun,0.07,options);  % may need to change starting values depanding on b and phi

        % matRate*(1-bbeta)*((1-pphi)*Ebar-z)-a*x(1)*rlbm

        thetaHat = xmin
        wbarHat = wbar

        matfile = fullfile(pwd,opts.output_path,'solutionDecentral.mat');

        save(matfile, 'thetaHat', 'wbarHat');

    elseif strcmpi(solveOpts.prob,'decentralparticipation')

        % options = optimoptions('fminsearch','Display','none','Diagnostics','off');
        options = optimset('Display','off','Diagnostics','off');
        obj_fun = @(wbarHat)ModelMaxWelf(wbarHat, initWbar, initTheta, params,order,opts,solveOpts);
        xmin=fminsearch(obj_fun,wbar,options);  % may need to change starting b and phi

        wbarHat = xmin

        solveOpts.prob = 'decentralparticipationfixed';

        options = optimoptions('fsolve','Display','none','Diagnostics','off','FunctionTolerance',1e-9,'MaxIterations',1000,'MaxFunctionEvaluations',2000,'OptimalityTolerance',1e-9);
        % options = optimset('Display','off','Diagnostics','off');
        obj_fun = @(theta)Model([theta; wbarHat],params,order,opts,solveOpts);
        [xmin,~]=fsolve(obj_fun,0.07,options);  % may need to change starting values depanding on b and phi

        thetaHat = xmin

        solveOpts.prob = 'decentralparticipation';

        matfile = fullfile(pwd,opts.output_path,'solutionDecentralParticipation.mat');

        save(matfile, 'thetaHat', 'wbarHat');

    elseif strcmpi(solveOpts.prob,'decentralparticipationfixed')

        % options = optimoptions('fminsearch','Display','none','Diagnostics','off','FunctionTolerance',1e-9,'MaxIterations',1000,'MaxFunctionEvaluations',2000,'OptimalityTolerance',1e-9);
        options = optimset('Display','off','Diagnostics','off');
        obj_fun = @(theta)Model([theta; wbar],params,order,opts,solveOpts);
        [xmin,~]=fsolve(obj_fun,0.08,options);  % may need to change starting values depanding on b and phi

        thetaHat = xmin
        wbarHat = wbar

        matfile = fullfile(pwd,opts.output_path,'solutionDecentralParticipation.mat');

        save(matfile, 'thetaHat', 'wbarHat');


    else
        % options = optimoptions('fminsearch','Display','none','Diagnostics','off','FunctionTolerance',1e-9,'MaxIterations',1000,'MaxFunctionEvaluations',2000,'OptimalityTolerance',1e-9);
        options = optimset('Display','off','Diagnostics','off');
        obj_fun = @(wbarHat)ModelMaxWelf(wbarHat,initWbar,initTheta,params,order,opts,solveOpts);
        % xmin=fminsearch(obj_fun,[0.08;max(6,(z/(1-pphi))+1)]);  % may need to change starting values depanding on b and phi
        xmin=fminsearch(obj_fun,wbar,options);  % may need to change starting values depanding on b and phi

        wbarHat=xmin

        solveOpts.prob = 'decentralfixed';

        options = optimoptions('fsolve','Display','none','Diagnostics','off','FunctionTolerance',1e-9,'MaxIterations',1000,'MaxFunctionEvaluations',2000,'OptimalityTolerance',1e-9);
        % options = optimset('Display','off','Diagnostics','off');
        obj_fun = @(theta)Model([theta; wbarHat],params,order,opts,solveOpts);
        [xmin,~]=fsolve(obj_fun,0.05,options);  % may need to change starting values depanding on b and phi

        thetaHat = xmin

        solveOpts.prob = 'decentral';


        matfile = fullfile(pwd,opts.output_path,'solutionDecentral.mat');

        save(matfile, 'thetaHat', 'wbarHat');
    end

end


end
