function welfare = ModelUIMaxWelf(deltBbar,initTheta,params,order,opts,solveOpts)
%%Model m-file for Labor Market Participation and the Minimum Wage
%Author: Adrian Masters and Ben Griffy
%Date: July 2020

% inputs
% x(1): market tightness (theta)
% wbarHat: cut-off productivity in planner's problem, minimum wage in decentralized problem.


[pphi,eeta,bbeta,a,z,r,llambda,m,mmu,ssigma,lb,ub,pphiDelt,zDelt,wbarDelt,wbinDelt,N,T,wbar,mFun,dmFun,wageFun,pFun,udotFun] = Parameters(params, order, opts);




if -z>deltBbar
    welfare=1
    % eqm=NaN
    % err = 1
    return
end

zHat = z + deltBbar;

    % Matching rate and matching rate derivative
    initMatRate = mFun(initTheta);
    initDmatRate = dmFun(initTheta);

    initSolveOpts = solveOpts.prob;
    solveOpts.prob = 'decentralfixed';


    options = optimoptions('fsolve','Display','none','Diagnostics','off','FunctionTolerance',1e-9,'MaxIterations',1000,'MaxFunctionEvaluations',2000,'OptimalityTolerance',1e-9);
    % options = optimset('Display','off','Diagnostics','off');
    obj_fun = @(theta)ModelUISysEq([theta; deltBbar],params,order,opts,solveOpts);
    [xmin,~]=fsolve(obj_fun,0.05,options);  % may need to change starting values depanding on b and phi

    solveOpts.prob = initSolveOpts;

    thetaHat = xmin

    % outcome calculations
    initUratem = llambda/(initMatRate+llambda);    % unemployment rate u/(u+e)


    matRate = mFun(thetaHat);
    dmatRate = dmFun(thetaHat);

    unempRateMat = (((((llambda+matRate).*initUratem-llambda)*ones(1,T.Trans+1)).*exp(-(llambda+matRate)*linspace(0,T.TransMax,T.Trans+1))+llambda)./(llambda+matRate)).';
    unempRateMat = (1 - logncdf(zHat,mmu,ssigma)).*unempRateMat;


    NILFRateMat = zeros(T.Trans+1,1);
    % NILFRateMat(1) = logncdf(initWbarHat,mmu,ssigma);
    % NILFRateMat(2:end) = logncdf(wbarHat,mmu,ssigma);
    NILFRateMat = repmat(logncdf(zHat,mmu,ssigma),T.Trans+1,1);


    empRateMat = zeros(T.Trans+1,1);
    empRateMat=(1-unempRateMat-NILFRateMat); % emplyment as share of totsal population
    % empRateMat(1) = 1 - (1 - logncdf(initWbarHat,mmu,ssigma))*(1 - initUratem) -  logncdf(initWbarHat,mmu,ssigma);


    uratem=llambda/(matRate+llambda);    % unemployment rate u/(u+e)

    NILF=logncdf(zHat,mmu,ssigma);   % share of poulation excluded from market

    empRate=(1-NILF)*(1-uratem); % emplyment as share of totsal population
    unempRate=1-empRate-NILF;

    welfNILF = repmat((zHat+(z-zHat)).*logncdf(zHat,mmu,ssigma),T.Trans+1,1);

    welfUnemp = unempRateMat.*(zHat+(z-zHat));

    welfEmp = (empRateMat./(1 - logncdf(zHat,mmu,ssigma))).*integral(@(x)(x.*lognpdf(x,mmu,ssigma)),zHat,inf);

    welfVac = -thetaHat.*unempRateMat.*a;

    welfVec = exp(-r.*linspace(0,T.TransMax,T.Trans+1).').*(welfNILF + welfUnemp + welfEmp + welfVac);

    % averaged welfare
    welfare = -((2*sum(welfVec)-welfVec(1)-welfVec(end))*(T.TransMax./T.Trans)./2 + welfVec(end)./r);




% eqm;

end
