function eqm = ModelUISysEq(x,params,order,opts,solveOpts)
%%Model m-file for Labor Market Participation and the Minimum Wage
%Author: Adrian Masters and Ben Griffy
%Date: July 2020

% inputs
% x(1): market tightness (theta)
% x(2): additional UI to offer to workers


[pphi,eeta,bbeta,a,z,r,llambda,m,mmu,ssigma,lb,ub,pphiDelt,zDelt,wbarDelt,wbinDelt,N,T,wbar,mFun,dmFun,wageFun,pFun,udotFun] = Parameters(params, order, opts);



eqm=zeros(2,1);

if x(1)<=0 || -z>x(2)
    eqm=10000*ones(2,1);
    % eqm=NaN
    % err = 1
    return
end

% matching rate at theta* and derivative of matching function at theta*
matRate = mFun(x(1));
dmatRate = dmFun(x(1));

phat = z+x(2);

% convenient definitions
rl=r+llambda;
rlm=r+llambda+matRate;
lm=llambda+matRate;
rlbm=r+llambda+bbeta*matRate;


% ps = pFun(x(2),x(1));

Fhat=logncdf(phat,mmu,ssigma);  % cum dist vlaue at wbar

fhat=lognpdf(phat,mmu,ssigma);     % density at wbar

Ep=LNCalcExp(params,order,opts,phat,inf);    % expected prod above wbar

Ehat = Ep - phat;
Eb = Ep - z;

% eq. 10 in sect. 3 of EER submission
% eqm(1)=matRate*(((integral(@(x)LNInt(x,mmu,ssigma),x(2),ps)*((ssigma*(2*pi)^(1/2))^-1)-(Fsq-Fbar)*x(2))/rl)+...
%                 (1-bbeta)*((1-pphi)*Esq-z)*(1-Fsq)/rlbm)-a*x(1)*(1-Fbar);  % (R.8.3) as modified in  (T.1.2)

eqm(1)=matRate*(1-bbeta)*Ehat-a*x(1)*rlbm; % Zp.3.7

csmu=-(Eb+a*x(1))/rlm;   % costate variable

umes=(1-Fhat)*llambda/lm;   % measure of steady state unemployed

dHdx=fhat*(((1-Fhat-umes)*Ehat/(1-Fhat))-Eb-csmu*llambda);  % Zp.4.2

dHdt=-umes*(a+csmu*dmatRate);    % Zp.4.0

dtdx=x(1)*rlbm*(fhat*Ehat-(1-Fhat))/((1-Fhat)*Ehat*((1-eeta)*rl+bbeta*matRate)); % Zp.5.5

eqm(2)=dHdx+dHdt*dtdx;    % S.3.1

if strcmpi(solveOpts.prob,'decentralfixed')
    eqm = eqm(1);
end


% eqm;

end
