function [pphi,eeta,bbeta,a,z,r,llambda,m,mmu,ssigma,lb,ub,pphiDelt,zDelt,wbarDelt,wbinDelt,N,T,wbar,mFun,dmFun,wageFun,pFun,udotFun] = Parameters(params, order, opts)
%%Parameters m-file for Labor Market Participation and the Minimum Wage
%Author: Adrian Masters and Ben Griffy
%Date: July 2020

%% Parameters Values

% Preferences and Technology
pphi    = params(find(strcmp(order, 'pphi'))); % share productivity achieved through non-market activity
eeta    = params(find(strcmp(order, 'eeta'))); % elasticity of matchng function
bbeta    = params(find(strcmp(order, 'bbeta'))); % bargiang power of the worker (was used for firm before Piss
% matching technology?)
a        = params(find(strcmp(order, 'a')));    % advertising cost
z        = params(find(strcmp(order, 'z'))); % benfits paid to unemplyed and discouraged/disabled
zDelt        = params(find(strcmp(order, 'zDelt'))); % benfits paid to unemplyed and discouraged/disabled
pphiDelt        = params(find(strcmp(order, 'pphiDelt'))); % discount rate
r        = params(find(strcmp(order, 'r'))); % discount rate
m        = params(find(strcmp(order, 'm'))); % scale parmater on the matching function
llambda = params(find(strcmp(order, 'llambda'))); % job destruction rate
mmu    = params(find(strcmp(order, 'mmu'))); % "mean parameter" of the log-normal
ssigma  = params(find(strcmp(order, 'ssigma'))); % s.d parameter
% ggamma        = params(find(strcmp(order, 'ggamma'))); % arrival rate of match specific shocks
% ubi = params(find(strcmp(order, 'ubi')));
% EITCSlopeA = params(find(strcmp(order, 'EITCSlopeA')));
% EITCSlopeB = params(find(strcmp(order, 'EITCSlopeB')));
% minEITC = params(find(strcmp(order, 'minEITC')));
% maxEITC = params(find(strcmp(order, 'maxEITC')));
% flatEITCA = params(find(strcmp(order, 'flatEITCA')));
% flatEITCB = params(find(strcmp(order, 'flatEITCB')));
% EITCCap = params(find(strcmp(order, 'EITCCap')));
lb.Eps        = params(find(strcmp(order, 'eplb')));    % lower bar (inf of suport for G) keep it strictly less than 1
ub.lp        = params(find(strcmp(order, 'pmax')));    % upper bound on the support of F (the maximum ability level)
N.p        = params(find(strcmp(order, 'NP')));    % length of the p vector
N.EpsTot        = params(find(strcmp(order, 'NEpsTot')));    % length of the epsilonhat vector
N.Eps1        = params(find(strcmp(order, 'NEps1')));    % length of epsiln hat vector below pe (typically 100)
N.Eps2        = params(find(strcmp(order, 'NEps2')));    % length of the epsilonhat (and epsilon squigle) vector between pe
%       and pn (typically 200)
N.Eps3        = params(find(strcmp(order, 'NEps3')));    % length of epsilon hat vector above pn (typically 1000)
N.Elast        = params(find(strcmp(order, 'NElast')));    % length of the minimum wage elasticity
T.Trans        = params(find(strcmp(order, 'TTrans')));    % length of the minimum wage elasticity
T.TransMax        = params(find(strcmp(order, 'TTransMax')));    % length of the minimum wage elasticity
wbar        = params(find(strcmp(order, 'wbar'))); % minimum wage
wbarDelt        = params(find(strcmp(order, 'wbarDelt'))); % minimum wage
wbinDelt        = params(find(strcmp(order, 'wbinDelt'))); % minimum wage

% lb.Eps        = 0;
% ub.lp        = 1;
% N.p        = 100;
% N.EpsTot        = 100;
% N.Eps1        = 20;
% N.Eps2        = 40;
% %       and pn (typically 200)
% N.Eps3        = 40;



init.ttheta        = params(find(strcmp(order, 'inittheta')));    % length of epsiln hat vector below pe (typically 100)
N.phat        = params(find(strcmp(order, 'phat')));    % length of the epsilonhat (and epsilon squigle) vector between pe
%       and pn (typically 200)


% Computed Parameters
mFun = @(theta)m.*theta.^eeta; % matching function
dmFun=@(theta)eeta.*mFun(theta)./theta;    % derivative of matching rate
uRateFun=@(theta)llambda/(mFun(theta)+llambda);    % unemployment rate u/(u+e)
wageFun = @(p,theta,minw)max((bbeta.*(r + llambda + mFun(theta)).*p + (1 - bbeta).*(r + llambda).*(pphi.*p + z))./(r + llambda + bbeta.*mFun(theta)),minw); % wage function
pFun = @(w,theta)(w.*(r + llambda + bbeta.*mFun(theta)) - z.*(r + llambda).*(1 - bbeta))./(bbeta.*(r + llambda + mFun(theta)) + (1 - bbeta).*(r + llambda).*pphi); % inverse wage function

udotFun = @(phat,theta,uCur)llambda.*(1 - logncdf(phat,mmu,ssigma) - uCur) - mFun(theta).*uCur;

% if strcmpi(opts.test,'UBI')
%     incFun = @(w)w + ubi;
% elseif strcmpi(opts.test,'UBIBernie')
%     incFun = @(w)w + 1.5.*ubi;
% elseif strcmpi(opts.test,'UBIBiden')
%     incFun = @(w)w + 0.5.*ubi;
% elseif strcmpi(opts.test,'EITC')
%     incFun = @(w)w + w.*EITCSlopeA.*(w >= minEITC & w < flatEITCA) + EITCCap.*(w>= flatEITCA & w < maxEITC) - (w - flatEITCB).*EITCSlopeB.*(w >= flatEITCB & w < maxEITC);
% elseif strcmpi(opts.test,'EITCFirstDollar')
%     incFun = @(w)w + EITCCap.*(w>= minEITC & w < maxEITC) - (w - flatEITCB).*EITCSlopeB.*(w >= flatEITCB & w < maxEITC);
% elseif strcmpi(opts.test,'EITCHighCap')
%     incFun = @(w)w + w.*2.*EITCSlopeA.*(w >= minEITC & w < flatEITCA) + 2.*EITCCap.*(w>= flatEITCA & w < maxEITC) - (w - flatEITCB).*2.*EITCSlopeB.*(w >= flatEITCB & w < maxEITC);
% else
%     incFun = @(w)w;
% end


end
