function [ssr,err] = SMM(params, order, moments, distMoments, opts)
%%SMM m-file for Labor Market Participation and the Minimum Wage
%Author: Adrian Masters and Ben Griffy
%Date: July 2020

opts.test = 'n';

[pphi,eeta,bbeta,a,z,r,llambda,m,mmu,ssigma,lb,ub,pphiDelt,zDelt,wbarDelt,wbinDelt,N,T,wbar,mFun,dmFun,wageFun,pFun,udotFun] = Parameters(params, order, opts);

% Solve model to obtain market tightness
if opts.SMM == 'y'
    solveOpts.prob = 'calib';
    err = ModelMaxWelf_Wrapper(params, order, opts, [], [], solveOpts);
end

% Calculate moments given market tightness
if err == 0

    % load market tightness
    matfile = fullfile(pwd,opts.output_path,'solutionCalib.mat');
    load(matfile);

    % Matching rate and matching rate derivative
    matRate = mFun(thetaHat);
    dmatRate = dmFun(thetaHat);

    % outcome calculations
    uratem=llambda/(matRate+llambda);    % unemployment rate u/(u+e)

    NILF=logncdf(wbar,mmu,ssigma);   % share of poulation excluded from market

    empRate=(1-NILF)*(1-uratem); % emplyment as share of totsal population

    % define new objects to limit line length
    rl=r+llambda;
    rlm=r+llambda+matRate;
    lm=llambda+matRate;
    rm=r+matRate;
    rlbm=r+llambda+bbeta*matRate;

    DENps=(bbeta*rlm)+(1-bbeta)*rl*pphi;

    % obtains psquigle the upper bound on productivity receiving the minimum wage
    ps=(rlbm*wbar-(1-bbeta)*rl*z)/DENps;

    % Spike at minimum wage
    spikem=max((logncdf(ps,mmu,ssigma)-NILF)/(1-NILF),0);

    tempProdDraws = lognrnd(mmu,ssigma,[10000,1]);
    tempProdDraws(tempProdDraws<wbar) = [];
    tempProdDraws(wageFun(tempProdDraws,thetaHat,wbar)>=30.5) = [];

    AveLnW = nanmean(log(wageFun(tempProdDraws,thetaHat,wbar)));
    SDLnW = std(log(wageFun(tempProdDraws,thetaHat,wbar)),'omitnan');

    model_moments = [uratem, NILF, AveLnW, SDLnW, spikem]

    diff = (moments - model_moments);

    % weight by magnitude of moments
    ssr = diff*diag(eye(size(diff,1))./abs(moments))*diff'

else
    ssr = NaN;
end

modelmomentnames = {'urate','nilf','AveLnW','SDLnW','spikem'};

if exist(fullfile(pwd,opts.SMM_path,'SMM.csv'), 'file')
    dlmwrite(fullfile(pwd,opts.SMM_path,'SMM.csv'),cat(2,ssr,model_moments,params(1:opts.nparams)'),'-append','precision',8);
else
    dlmwrite(fullfile(pwd,opts.SMM_path,'SMM.csv'),cat(2,'ssr,',strjoin(modelmomentnames,','),',',sprintf('%s,',order{1:opts.nparams})),'');
    dlmwrite(fullfile(pwd,opts.SMM_path,'SMM.csv'),cat(2,ssr,reshape(model_moments,1,[]),params(1:opts.nparams)'),'-append','precision',8);
end

if exist(fullfile(pwd,opts.SMM_path,'SSR.csv'), 'file')
    dlmwrite(fullfile(pwd,opts.SMM_path,'SSR.csv'),cat(2,ssr,reshape(diff,1,[]),params(1:opts.nparams)'),'-append','precision',8);
else
    dlmwrite(fullfile(pwd,opts.SMM_path,'SSR.csv'),cat(2,'ssr,',strjoin(modelmomentnames,','),',',sprintf('%s,',order{1:opts.nparams})),'');
    dlmwrite(fullfile(pwd,opts.SMM_path,'SSR.csv'),cat(2,ssr,reshape(diff,1,[]),params(1:opts.nparams)'),'-append','precision',8);
end

end
